<?php
session_start(); // Start the session

// Include your database connection file
require_once('conn.php');

// ✅ Check if the user is logged in
if (!isset($_SESSION['name']) || !isset($_SESSION['zone']) || !isset($_SESSION['email'])) {
    header("Location: index.php");
    exit();
}

// ✅ Get logged-in coordinator details
$coordinator_name = $_SESSION['name'];
$coordinator_zone = $_SESSION['zone'];
$coordinator_email = $_SESSION['email'];

// ✅ Don't overwrite `$_SESSION['freshLogin']`, just check its value
$freshLogin = isset($_SESSION['freshLogin']) && $_SESSION['freshLogin'];
$zone = $_SESSION['zone']; // Get the zone from the session
$currentYear = date('Y'); // Get the current year
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RCCG DTCE | Change Password</title>

    <!-- Dependencies -->
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="dist/css/custom.css">
    <link rel="stylesheet" href="dist/css/login_style.css">
    <link rel="stylesheet" href="assets/css/mystyle.css">
    <link rel="stylesheet" href="newstyle.css">
    <link rel="stylesheet" href="dist/css/animate.min.css">
    <link href="plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-icons/1.8.1/font/bootstrap-icons.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

    <!-- AdminLTE -->


    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>

</head>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">
        <!-- Navbar -->
        <nav class="main-header navbar navbar-expand-lg navbar-light">
            <div class="container-fluid">
                <!-- Navbar Toggler for Mobile -->
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
                    aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <!-- Left Navbar Links -->
                <a href="#" class="navbar-brand">
                    <img src="./dist/img/dtce.png" alt="Logo" style="height: 40px;">
                </a>

                <?php
                include 'conn.php';
                $zone = $_SESSION['zone']; // Get the province name from the session

                // Fetch the count of unread notifications for this province
                $stmt = $conn->prepare("SELECT COUNT(*) as count FROM zonenotifications WHERE zone = :zone AND is_read = 0");
                $stmt->bindValue(':zone', $zone);
                $stmt->execute();
                $count = $stmt->fetch(PDO::FETCH_ASSOC)['count'];
                ?>

                <div class="collapse navbar-collapse" id="navbarNav">
                    <ul class="navbar-nav">
                        <li class="nav-item">
                            <a class="nav-link" data-widget="pushmenu" href="#" role="button">
                                <i class="fas fa-bars"></i>
                            </a>
                        </li>
                    </ul>

                    <!-- Centered Search Form -->
                    <form class="form-inline mx-auto">
                        <input class="form-control mr-sm-2" type="search" placeholder="Search" aria-label="Search">
                        <button class="btn btn-outline-primary my-2 my-sm-0" type="submit">
                            <i class="fas fa-search"></i>
                        </button>
                    </form>

                    <!-- Right Navbar Links -->
                    <ul class="navbar-nav ml-auto">
                        <li class="nav-item">
                            <a class="nav-link" href="#">
                                <img src="./dist/img/ng3.webp" alt="Flag" style="width: 35px;">
                            </a>
                        </li>

                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="notificationDropdown" role="button"
                                data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                <i class="fas fa-bell">
                                    <span class="badge badge-danger"><?php echo $count; ?></span>
                                </i>
                            </a>
                            <div class="dropdown-menu dropdown-menu-right" aria-labelledby="notificationDropdown"
                                id="notificationList">

                            </div>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="#" id="theme-toggle">
                                <i id="theme-icon" class="fas fa-sun"></i> <!-- Default icon is sun -->
                            </a>
                        </li>

                        <li class="nav-item dropdown">
                            <a class="nav-link d-flex align-items-center dropdown-toggle" data-toggle="dropdown" href="#">
                                <?php
                                // Get the session zone
                                $zone = $_SESSION["zone"];

                                // Ensure it follows the correct format: "Zone X – Region Name"
                                $zone_parts = explode(" ", $zone);

                                // Ensure there are enough parts
                                if (count($zone_parts) >= 4) {
                                    $zone_number = $zone_parts[1]; // Extracts "1" from "Zone 1"

                                    // Handle cases with multiple dashes (e.g., "Zone 3 – South – South Regions")
                                    $region_name = "";
                                    for ($i = 3; $i < count($zone_parts); $i++) {
                                        if ($zone_parts[$i] !== "–") {
                                            $region_name .= substr($zone_parts[$i], 0, 1); // Take first letter of each word
                                        }
                                    }

                                    // Format the result as "ZN X-XX"
                                    $formatted_zone = "ZN $zone_number-$region_name";
                                } else {
                                    $formatted_zone = "ZN -"; // Fallback for incorrect formats
                                }

                                // Display the formatted zone name with profile image
                                echo '<div class="province-initials d-flex align-items-center" 
                                style="background-color:rgb(189, 8, 8); color: white; padding: 8px 12px; border-radius: 50px; display: flex; align-items: center; font-weight: bold; font-size: 16px; min-width: 100px;">
                                    <img src="dist/img/icon.png" alt="Profile" style="width: 35px; height: 35px; border-radius: 50%; margin-right: 8px;">
                                    ' . $formatted_zone . '
                                </div>';
                                ?>


                                <div style="display: flex; flex-direction: column; color: white;">
                                    <span class="d-none d-md-inline"><?php echo strtoupper($_SESSION["name"]) ?></span>
                                    <small style="color: white;"><?php echo $_SESSION["zone"] ?></small>
                                </div>

                            </a>
                            <div class="dropdown-menu dropdown-menu-lg dropdown-menu-right">
                                <a href="#" class="dropdown-item"><i class="fas fa-user"></i> My Profile</a>
                                <a href="#" class="dropdown-item"><i class="fas fa-cog"></i> Settings</a>
                                <div class="dropdown-divider"></div>
                                <a href="logout.php" class="dropdown-item"><i class="fas fa-sign-out-alt"></i> Logout</a>
                            </div>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
    </div>
    
<?php
session_start(); // ✅ Add this if missing
include 'conn.php';

include 'conn.php';

// ✅ Check if the user is logged in
if (!isset($_SESSION['zone'])) {
    header("Location: index.php");
    exit();
}

$zone = $_SESSION['zone']; // The zone is stored in the session

// ✅ Fetch current password and password change status
$stmt = $conn->prepare("SELECT password, password_changed FROM zone WHERE zone = :zone");
$stmt->bindParam(':zone', $zone);
$stmt->execute();
$userData = $stmt->fetch(PDO::FETCH_ASSOC);

// ✅ Redirect if user data is not found
if (!$userData) {
    header("Location: index.php");
    exit();
}

$currentPassword = $userData['password'];
$passwordChanged = $userData['password_changed'];

// ✅ Set freshLogin properly
if ($passwordChanged == 0) {
    $_SESSION['freshLogin'] = true;
} else {
    $_SESSION['freshLogin'] = false;
}

// ✅ Handle password change form submission
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['change_password'])) {
    $userInputPassword = trim($_POST['new_password']); 

    // ✅ Validate password format (6 characters, at least 1 uppercase, 1 lowercase, 1 number, 1 special character)
    if (
        strlen($userInputPassword) !== 6 ||
        !preg_match('/[A-Z]/', $userInputPassword) ||
        !preg_match('/[a-z]/', $userInputPassword) ||
        !preg_match('/[0-9]/', $userInputPassword) ||
        !preg_match('/[\W]/', $userInputPassword)
    ) {
        $errorMessage = "Password must be exactly 6 characters long and include at least one uppercase letter, one lowercase letter, one number, and one special character.";
    } else {
        $newPassword = "dtce" . $userInputPassword; // ✅ Append prefix

        // ✅ Update database
        $stmt = $conn->prepare("UPDATE zone SET password = :newPassword, password_changed = 1 WHERE zone = :zone");
        $stmt->bindParam(':newPassword', $newPassword);
        $stmt->bindParam(':zone', $zone);

       if ($stmt->execute()) {
    $_SESSION['freshLogin'] = false; 
    $_SESSION['password_changed'] = true;

    ob_clean(); // ✅ Clears any accidental output
    header("Location: main.php");
    exit();

        } else {
            $errorMessage = "Error updating password. Please try again.";
        }
    }
}
?>

    <!-- /.navbar -->



    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <div class="user-panel mt-3 pb-3 mb-3 d-flex align-items-center">
            <div class="image">
                <img src="./dist/img/icon.png" alt="User Image">
            </div>
            <div class="info">
                <a href="#" class="company-name" style="color:aliceblue">RCCG DTCE</a>
            </div>
        </div>
        <!-- Sidebar Menu -->
        <nav class="mt-2">
            <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                <!-- Static menu items -->
                <?php
                $staticMenu = [
                    ["link" => "main.php", "icon" => "fa-chart-pie", "name" => "Dashboard"],
                    ["link" => "zonepayments.php", "icon" => "fa-money-bill-wave", "name" => "Payments"],
                    ["link" => "quiz.php", "icon" => "fa-file-alt", "name" => "Quiz Report"],
                    ["link" => "sport.php", "icon" => "fa-running", "name" => "Sport Report"],
                    ["link" => "choir.php", "icon" => "fa-microphone", "name" => "Choir Report"],
                    ["link" => "zoneregions.php", "icon" => "fa-globe", "name" => "Regions Details"],
                    ["link" => "zoneprovinces.php", "icon" => "fa-map-marker-alt", "name" => "Provinces Details"],
                    ["link" => "settings.php", "icon" => "fa-cog", "name" => "Settings"]

                ];

                foreach ($staticMenu as $item):
                    $disabledClass = (isset($_SESSION['freshLogin']) && $_SESSION['freshLogin']) ? 'disabled' : '';
                    $link = $disabledClass ? '#' : htmlspecialchars($item['link']);
                ?>
                    <li class="nav-item">
                        <a href="<?php echo $link; ?>" class="nav-link <?php echo $disabledClass; ?>"
                            <?php if ($disabledClass) echo 'style="pointer-events: none; color: gray; cursor: not-allowed;" onclick="event.preventDefault(); showMessage();"'; ?>>
                            <i class="nav-icon fas <?php echo htmlspecialchars($item['icon']); ?>" style="color: white !important;"></i>
                            <p style="color: white !important;"><?php echo htmlspecialchars($item['name']); ?></p>
                        </a>
                    </li>
                <?php endforeach; ?>

                <!-- Zone Coordinator Menu -->
                <li class="nav-item has-treeview">
                    <a href="#" class="nav-link" data-toggle="collapse" data-target="#zoneMenu">
                        <i class="nav-icon fas fa-users-cog" style="color: white !important;"></i>
                        <p class="menu-text" style="color: white !important;">Provincial Coord Menus <i class="right fas fa-angle-left"></i></p>
                    </a>
                    <ul id="zoneMenu" class="nav nav-treeview collapse">
                        <?php foreach ($menuItems as $item): ?>
                            <li class="nav-item">
                                <a href="#" class="nav-link" style="pointer-events: none; opacity: 0.5; cursor: default;">
                                    <i class="nav-icon fas <?php echo htmlspecialchars($item['icon']); ?>" style="color: white !important;"></i>
                                    <p style="color: white !important;"><?php echo htmlspecialchars($item['name']); ?></p>
                                </a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </li>

            </ul>
            </div>
            </div>
            </div>
            </div>
    </aside>
    </nav>


    <script>
        function showMessage() {
            alert("This menu is for Zone Coordinators only.");
        }

        document.addEventListener("DOMContentLoaded", function() {
            const sidebar = document.querySelector(".main-sidebar");
            const menuText = document.querySelectorAll(".menu-text");

            function toggleMenuText() {
                if (sidebar.classList.contains("sidebar-collapse")) {
                    menuText.forEach(text => text.style.display = "none");
                } else {
                    menuText.forEach(text => text.style.display = "inline");
                }
            }

            toggleMenuText();
            document.body.addEventListener("classChange", toggleMenuText);
        });
    </script>


    <!-- Bootstrap Alert (Initially Hidden) -->
    <div id="passwordAlert" class="alert alert-warning alert-dismissible fade show" role="alert" style="display: none;">
        <strong>Please change your password before proceeding.</strong>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>

    <script>
        // Function to show the Bootstrap alert when a disabled menu item is clicked
        function showAlert() {
            // Show the alert by setting display to block
            var alertBox = document.getElementById("passwordAlert");
            if (alertBox) {
                alertBox.style.display = "block";
                // Optional: Hide alert after 3 seconds
                setTimeout(function() {
                    alertBox.style.display = "none";
                }, 3000);
            }
        }
    </script>


    <!-- /.sidebar-menu -->
    </div>
    <!-- /.sidebar -->
    </aside>
    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <!-- Breadcrumb -->
        <div class="breadcrumb-wrapper">
            <ul class="breadcrumb">
                <li class="breadcrumb-item"><a href="../../index.php">HOME</a></li>
                <li class="breadcrumb-item active">Change Password</li>
            </ul>
        </div>

        <?php include("news.php"); ?>
        <!-- Main content -->

        <section class="content">
            <?php
            include 'conn.php';

            // Fetch the cover picture
            $stmt = $conn->query("SELECT * FROM cover_pic ORDER BY id DESC LIMIT 1");
            $coverPic = $stmt->fetch(PDO::FETCH_ASSOC);
            $imagePath = $coverPic ? $coverPic['image_path'] : './dist/img/bg-login.jpg'; // Default image if none found
            ?>

            <div class="row">
                <div class="col-sm-12">
                    <div class="profile-bg-picture" style="background-image: url('<?php echo htmlspecialchars($imagePath); ?>');">
                        <div class="picture-bg-overlay"></div>
                    </div>
                </div>
            </div>
            <?php
            // Check if password has been changed
            $isPasswordChanged = isset($_SESSION['password_changed']) && $_SESSION['password_changed'] === true;
            ?>

            <section class="w-100 page-section pb-5 pt-5">
                <div class="container">
                    <div class="row justify-content-center align-items-center">
                        <div class="col-lg-8 d-flex flex-column align-items-center">
                            <h1 class="h2 text-center">Change Your Password</h1>
                            <hr class="divider my-4">

                            <?php if (!$isPasswordChanged): ?>
                                <!-- Message Card for password change requirement -->
                                <div id="passwordChangeMessage" class="alert alert-warning alert-dismissible fade show w-100" role="alert">
                                    <div class="d-flex justify-content-between align-items-center">
                                        <p style="font-size: 16px; margin: 0; padding: 0;">
                                            <strong>Important:</strong> Your account menus are disabled because you need to change your password. Please update your password to enable access to all features.
                                        </p>
                                    </div>
                                </div>
                            <?php endif; ?>

                        </div>


                        <div class="col-lg-6 col-md-8 col-sm-12">
                            <div class="card mx-3 shadow-lg rounded">
                                <div class="card-body text-center">
                                    <h5 class="card-title font-weight-bold mb-3">We need you to change your password!</h5>
                                    <p class="text-muted">For your security, please choose a new password.</p>
                                </div>

                                <div class="card-body">
                                    <!-- Show Current Password -->
                                    <div class="form-group">
                                        <label for="current_password">Current Password:</label>
                                        <input type="text" class="form-control" id="current_password" value="<?php echo htmlspecialchars($currentPassword); ?>" readonly>
                                    </div>

                                    <!-- Start Form -->
                                    <form method="POST">
                                        <div class="form-group mt-4 mb-3 position-relative">
                                            <label for="new_password">New Password (6 characters):</label>
                                            <div class="input-group">
                                                <div class="input-group-prepend">
                                                    <span class="input-group-text">dtce</span>
                                                </div>
                                                <input type="password" class="form-control form-control-lg" name="new_password" id="new_password" required maxlength="6" pattern=".{6,6}" title="Password must be exactly 6 characters" placeholder="Enter 6 characters" onkeyup="checkPasswordStrength()">
                                                <div class="input-group-append">
                                                    <button class="btn btn-outline-secondary" type="button" onclick="togglePassword()">Show</button>
                                                </div>
                                            </div>
                                            <small id="passwordHelp" class="form-text mt-2"></small>
                                        </div>

                                        <!-- Submit Button -->
                                        <div class="form-group mt-4 mb-3">
                                            <button type="submit" class="btn btn-block btn-primary submitBtn text-center px-5" name="change_password">Change Password</button>
                                        </div>
                                    </form>
                                    <!-- End Form -->

                                    <!-- Close Button -->
                                    <div class="form-group text-center mb-4">
                                        <a href="change-password.php" class="btn btn-outline-secondary">Close</a>
                                    </div>

                                    <?php if (!empty($errorMessage)) : ?>
                                        <div class="alert alert-danger mt-3"><?php echo $errorMessage; ?></div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
        </section>
    </div>

    <script>
        // Check if password was changed and hide the message
        <?php if ($isPasswordChanged): ?>
            document.getElementById("passwordChangeMessage").style.display = "none";
        <?php endif; ?>

        // Hide the message after 5 seconds (you can adjust the delay as needed)
        setTimeout(function() {
            var messageCard = document.getElementById("passwordChangeMessage");
            if (messageCard) {
                messageCard.style.display = "none"; // Hide the message
            }
        }, 10000); // Hide after 5 seconds
    </script>

    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- CSS for Blinking Effect -->
    <style>
        @keyframes blink {
            0% {
                opacity: 1;
            }

            50% {
                opacity: 0;
            }

            100% {
                opacity: 1;
            }
        }

        #passwordChangeMessage {
            animation: blink 1.5s infinite;
            /* Adjust the duration to control blinking speed */
        }
    </style>




    <!-- JavaScript for Show/Hide Password and Strength Checking -->
    <script>
        function togglePassword() {
            var passwordField = document.getElementById("new_password");
            var button = event.target;

            if (passwordField.type === "password") {
                passwordField.type = "text";
                button.textContent = "Hide";
            } else {
                passwordField.type = "password";
                button.textContent = "Show";
            }
        }

        function checkPasswordStrength() {
            var password = document.getElementById("new_password").value;
            var passwordHelp = document.getElementById("passwordHelp");

            // Check individual criteria
            var hasUpperCase = /[A-Z]/.test(password);
            var hasLowerCase = /[a-z]/.test(password);
            var hasNumber = /[0-9]/.test(password);
            var hasSpecialChar = /[\W]/.test(password); // Matches special characters
            var isCorrectLength = password.length === 6;

            var strength = 0;

            if (isCorrectLength) strength++;
            if (hasUpperCase) strength++;
            if (hasLowerCase) strength++;
            if (hasNumber) strength++;
            if (hasSpecialChar) strength++;

            // Update strength message based on score
            if (!isCorrectLength) {
                passwordHelp.textContent = "Password must be exactly 6 characters.";
                passwordHelp.style.color = "red";
            } else if (strength < 3) {
                passwordHelp.textContent = "Weak password. Try adding uppercase, numbers, and special characters.";
                passwordHelp.style.color = "red";
            } else if (strength === 3 || strength === 4) {
                passwordHelp.textContent = "Medium strength. Consider making it stronger!";
                passwordHelp.style.color = "orange";
            } else {
                passwordHelp.textContent = "Strong password!";
                passwordHelp.style.color = "green";
            }
        }
    </script>

    <!-- Optional: Custom styles to support dark and light mode -->
    <style>
        /* For light mode */
        .card {
            background-color: #fff;
            color: #000;
        }

        .card-body {
            background-color: #f8f9fa;
        }

        .divider {
            border-top: 2px solid #ccc;
        }

        .btn-outline-secondary {
            border-color: #6c757d;
            color: #6c757d;
        }

        /* For dark mode */
        body[data-theme="dark"] .card {
            background-color: #333;
            color: #fff;
        }

        body[data-theme="dark"] .card-body {
            background-color: #444;
        }

        body[data-theme="dark"] .btn-outline-secondary {
            border-color: #6c757d;
            color: #ddd;
        }
    </style>


    <?php
    include 'conn.php'; // Make sure this file contains your database connection

    // Fetch the modal content from the database
    $stmt = $conn->query("SELECT message FROM modal_content ORDER BY id DESC LIMIT 1");
    $modalContent = $stmt->fetch(PDO::FETCH_ASSOC);
    $message = $modalContent['message'];
    ?>

    <!-- Modal HTML -->
    <div id="announcementModal" class="modal">
        <div class="modal-content">
            <span class="close-btn" onclick="closeModal()">&times;</span>
            <h2>🎉 Welcome to the New Convention Portal! 🎉</h2>
            <p>
                <?php echo $message; ?>
            </p>
        </div>
    </div>
    <!-- Toast Container -->
    <div class="toast-container" style="position: absolute; top: 20px; right: 20px;">
        <!-- Toast HTML -->
        <div class="toast" id="myToast" role="alert" aria-live="assertive" aria-atomic="true" data-delay="3000">
            <div class="toast-header">
                <strong class="mr-auto">Welcome Message</strong>
                <small class="text-muted">just now</small>
                <button type="button" class="ml-2 mb-1 close" data-dismiss="toast" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="toast-body" id="toastBody">
                <p>Welcome back, <?php echo htmlspecialchars($_SESSION['zone'], ENT_QUOTES, 'UTF-8'); ?>! We are glad to have you here.</p>
            </div>
        </div>
    </div>


    <!-- /.content-wrapper -->

    <!-- Footer -->
    <?php
    include 'conn.php'; // Ensure this file contains your database connection

    // Fetch footer content from the footer table
    $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
    $footer = $stmt->fetch(PDO::FETCH_ASSOC);
    $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
    $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
    ?>
    <footer class="main-footer text-sm">
        <div class="text-xs" id="copyright">
            <?php echo $copyrightMessage; ?>
            <div class="float-right d-none d-sm-inline-block">
                <b><?php echo $eventInfo; ?></b>
            </div>
        </div>
    </footer>

    <!-- ./wrapper -->

    <script>
        // Function to show the toast
        function showToast() {
            const toast = document.getElementById('myToast');
            $(toast).toast('show'); // Manually trigger the toast
        }

        // Auto-trigger the toast on page load
        window.onload = function() {
            showToast();
        };
    </script>


    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Check if the modal has been closed previously
            if (!localStorage.getItem("modalClosed")) {
                // Show the modal if not closed
                document.getElementById("announcementModal").style.display = "block";
            }
        });

        function closeModal() {
            // Hide the modal
            document.getElementById("announcementModal").style.display = "none";
            // Set a flag in localStorage to indicate that the modal has been closed
            localStorage.setItem("modalClosed", "true");
        }
    </script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const toggle = document.getElementById('theme-toggle');
            const icon = document.getElementById('theme-icon');

            function applyDarkMode() {
                document.body.classList.add('dark-mode');
                document.body.classList.remove('light-mode');
                if (icon) {
                    icon.classList.remove('fa-sun');
                    icon.classList.add('fa-moon');
                }
                localStorage.setItem('theme', 'dark');
            }

            function applyLightMode() {
                document.body.classList.add('light-mode');
                document.body.classList.remove('dark-mode');
                if (icon) {
                    icon.classList.remove('fa-moon');
                    icon.classList.add('fa-sun');
                }
                localStorage.setItem('theme', 'light');
            }

            // Check and apply the saved theme
            if (localStorage.getItem('theme') === 'dark') {
                applyDarkMode();
            } else {
                applyLightMode();
            }

            // Toggle event listener
            if (toggle) {
                toggle.addEventListener('click', function() {
                    if (document.body.classList.contains('dark-mode')) {
                        applyLightMode();
                    } else {
                        applyDarkMode();
                    }
                });
            }
        });
    </script>
    <script>
        $(document).ready(function() {
            $('#notificationDropdown').on('click', function() {
                $.ajax({
                    url: 'fetch_notifications.php',
                    type: 'GET',
                    data: {
                        province: '<?php echo $_SESSION['pro']; ?>'
                    },
                    dataType: 'json',
                    success: function(data) {
                        console.log('Fetched notifications:', data);
                        let notificationList = $('#notificationList');
                        notificationList.empty();

                        if (data.length === 0) {
                            notificationList.append(
                                '<div class="dropdown-item">No Notifications</div>');
                        } else {
                            data.forEach(notification => {
                                let createdDate = new Date(notification.created_at);
                                let formattedDate = formatDate(createdDate);
                                let timeAgo = timeSince(createdDate);
                                let unreadBadge = notification.is_read === 0 ?
                                    '<span class="badge badge-danger">Unread</span>' :
                                    '';

                                notificationList.append(`
                            <a class="dropdown-item" href="read_notification.php?id=${notification.id}">
                                ${unreadBadge} ${notification.message}
                                <small class="text-muted">${formattedDate} (${timeAgo})</small>
                            </a>
                        `);
                            });
                        }

                        $('.badge-danger').text(data.length);
                    },
                    error: function(xhr, status, error) {
                        console.error('Error loading notifications:', error);
                    }
                });
            });
        });

        function formatDate(date) {
            const options = {
                day: 'numeric',
                month: 'short',
                year: 'numeric'
            };
            let day = date.getDate();
            let month = date.toLocaleString('default', {
                month: 'short'
            });
            let suffix = day % 10 === 1 && day !== 11 ? 'st' :
                day % 10 === 2 && day !== 12 ? 'nd' :
                day % 10 === 3 && day !== 13 ? 'rd' : 'th';
            return `${day}${suffix} ${month}, ${date.getFullYear()}`;
        }

        function timeSince(date) {
            const seconds = Math.floor((new Date() - date) / 1000);
            let interval = Math.floor(seconds / 31536000);
            if (interval > 1) return interval + " years ago";
            interval = Math.floor(seconds / 2592000);
            if (interval > 1) return interval + " months ago";
            interval = Math.floor(seconds / 86400);
            if (interval > 1) return interval + " days ago";
            interval = Math.floor(seconds / 3600);
            if (interval > 1) return interval + " hours ago";
            interval = Math.floor(seconds / 60);
            if (interval > 1) return interval + " minutes ago";
            return seconds + " seconds ago";
        }
    </script>
    <!-- Scripts -->
    <script src="plugins/jquery/jquery.min.js"></script>
    <script src="plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
    <script src="plugins/sweetalert2/sweetalert2.min.js"></script>
    <script src="plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
    <script src="dist/js/adminlte.min.js"></script>
    <script defer src="scripts/cookies/cookieconsent.js"></script>
    <script defer src="scripts/cookies/cookieconsent-init.js"></script>
    <script src="plugins/jquery-validation/jquery.validate.min.js"></script>
    <script src="plugins/jquery-validation/additional-methods.min.js"></script>
    <!-- Include jQuery and Bootstrap JS -->

    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>




</body>

</html>