<?php
session_start(); // Start session
if (isset($_POST['province'])) {
    $_SESSION['pro'] = $_POST['province'];
}

require_once("conn.php"); // Include database connection

// Check if the form was submitted
if (isset($_POST['checkout'])) {
    // Sanitize and validate inputs
    $name = htmlspecialchars(trim($_POST['name']));
    $email = filter_var(trim($_POST['email']), FILTER_VALIDATE_EMAIL);
    $phoneNumber = htmlspecialchars(trim($_POST['phone_number']));
    $referenceCode = htmlspecialchars(trim($_POST['teller_number']));
    $region = htmlspecialchars(trim($_POST['region']));
    $zone = htmlspecialchars(trim($_POST['zone']));

    // Use the province from the session, since the zone registers for it
    if (isset($_SESSION['pro'])) {
        $province = $_SESSION['pro'];
    } else {
        echo '<script>alert("Session expired. Please start a new application."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    if (!$email) {
        echo '<script>alert("Invalid email address."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Initialize ticket counts
    $p1 = $p2 = $p3 = 0;
    $cartTotal = 0;

    // Fetch product details from database
    $stmt = $conn->query("SELECT id, name FROM products");
    $productMapping = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Map product IDs to types
    $productTypes = [];
    foreach ($productMapping as $product) {
        switch (strtolower($product['name'])) {
            case 'children\'s ticket':
                $productTypes[$product['id']] = 'p1';
                break;
            case 'teens ticket':
                $productTypes[$product['id']] = 'p2';
                break;
            case 'teacher\'s ticket':
                $productTypes[$product['id']] = 'p3';
                break;
        }
    }

    // Process cart items
    if (!empty($_SESSION['cart'])) {
        foreach ($_SESSION['cart'] as $item) {
            $itemPrice = $item['price'];
            $itemQuantity = $item['quantity'];
            $productId = $item['id'];

            if (isset($productTypes[$productId])) {
                $type = $productTypes[$productId];
                if ($type == 'p1') $p1 += $itemQuantity;
                if ($type == 'p2') $p2 += $itemQuantity;
                if ($type == 'p3') $p3 += $itemQuantity;
            }

            $cartTotal += $itemPrice * $itemQuantity;
        }
    } else {
        echo '<script>alert("Your cart is empty. Please add items before proceeding to checkout."); window.location.href = "shop.php";</script>';
        exit();
    }

    if ($p1 + $p2 + $p3 < 1) {
        echo '<script>alert("Minimum registration is 1 ticket."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Check for incomplete registrations in the province
    $stmt = $conn->prepare("SELECT * FROM registration WHERE province = ? AND (p1 != p1c OR p2 != p2c OR p3 != p3c)");
    $stmt->execute([$province]);
    $incompleteRegistration = $stmt->fetch();

    if ($incompleteRegistration) {
        echo '<script>alert("Complete previous registration for this province before proceeding."); window.location.href = "regcontinue.php";</script>';
        exit();
    }

    // Check for duplicate registration
    $stmt = $conn->prepare("SELECT COUNT(*) FROM registration WHERE name = ? AND email = ? AND phone_number = ? AND password = ?");
    $stmt->execute([$name, $email, $phoneNumber, $referenceCode]);
    $recordExists = $stmt->fetchColumn();

    if ($recordExists) {
        echo '<script>alert("A similar registration already exists. Please avoid duplicate entries."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Save details into the registration table
    $registrationDateTime = date("l, jS F - h:i:s A");
    $registrationYear = date("Y");

    $stmt = $conn->prepare("INSERT INTO registration (name, email, phone_number, password, zone, region, province, p1, p2, p3, amount, date, year) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
    $success = $stmt->execute([
        $name,
        $email,
        $phoneNumber,
        $referenceCode,
        $zone, // Zone registering
        $region,
        $province, // Province being registered
        $p1,
        $p2,
        $p3,
        $cartTotal,
        $registrationDateTime,
        $registrationYear
    ]);

    if ($success) {
        $_SESSION['registration_details'] = [
            'name' => $name,
            'email' => $email,
            'phone_number' => $phoneNumber,
            'reference_code' => $referenceCode,
            'zone' => $zone,
            'region' => $region,
            'province' => $province,
            'p1' => $p1,
            'p2' => $p2,
            'p3' => $p3,
            'amount' => $cartTotal,
            'registration_date_time' => $registrationDateTime,
            'registration_year' => $registrationYear
        ];

        unset($_SESSION['cart']);

        echo '<script>
            alert("Thank you, you have booked ' . ($p1 + $p2 + $p3) . ' Registration Tickets.");
            window.location.href = "summary.php?registration_id=' . htmlspecialchars($referenceCode, ENT_QUOTES, 'UTF-8') . '";
        </script>';
        exit();
    } else {
        echo '<script>alert("There was an error processing your registration. Please try again."); window.location.href = "newregistration.php";</script>';
        exit();
    }
}

?>
