<?php
require_once('tcpdf/tcpdf.php'); // Include TCPDF library
include 'conn.php'; // Include database connection

if (!isset($_GET['rrr'])) {
    die("Invalid request.");
}

$teller_number = $_GET['rrr'];

try {
    // Fetch payment details
    $stmt = $conn->prepare("SELECT * FROM bank WHERE rrr = ?");
    $stmt->execute([$teller_number]);
    $payment = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$payment || $payment['status'] !== 'Approved') {
        die("Payment not approved or not found.");
    }
} catch (PDOException $e) {
    die("Database error: " . $e->getMessage());
}

// Create new PDF document
$pdf = new TCPDF('P', 'mm', 'A4', true, 'UTF-8', false);
$pdf->SetTitle('Payment Receipt');
$pdf->SetMargins(10, 10, 10);
$pdf->AddPage();

// Receipt Header
$html = '
    <h2 style="text-align:center; color:#186F45;">RCCG DTCE - E-Receipt</h2>
    <p style="text-align:center;"><strong>Transaction Details</strong></p>
    <hr>
    <table border="1" cellpadding="5">
        <tr>
            <td><strong>Payer\'s Name:</strong></td>
            <td>' . htmlspecialchars($payment['name']) . '</td>
        </tr>
        <tr>
            <td><strong>Province:</strong></td>
            <td>' . htmlspecialchars($payment['province']) . '</td>
        </tr>
        <tr>
            <td><strong>Registration Code:</strong></td>
            <td>' . htmlspecialchars($payment['rrr']) . '</td>
        </tr>
        <tr>
            <td><strong>Transaction Reference:</strong></td>
            <td>' . htmlspecialchars($payment['ref']) . '</td>
        </tr>
        <tr>
            <td><strong>Amount Paid:</strong></td>
            <td>₦' . number_format($payment['cash'], 2) . '</td>
        </tr>
        <tr>
            <td><strong>Payment Date:</strong></td>
            <td>' . date('l, jS F, Y', strtotime($payment['date_of_payment'])) . '</td>
        </tr>
        <tr>
            <td><strong>Date Approved:</strong></td>
            <td>' . date('l, jS F, Y', strtotime($payment['date'])) . '</td>
        </tr>
        <tr>
            <td><strong>Mode of Payment:</strong></td>
            <td>' . htmlspecialchars($payment['mode']) . '</td>
        </tr>
        <tr>
            <td><strong>Bank Name:</strong></td>
            <td>' . htmlspecialchars($payment['bank']) . '</td>
        </tr>
        <tr>
            <td><strong>Status:</strong></td>
            <td><strong style="color:green;">' . htmlspecialchars($payment['status']) . '</strong></td>
        </tr>
    </table>
    <br>
    <p style="text-align:center;"><strong>Thank you for your payment!</strong></p>
';

// Output the HTML content
$pdf->writeHTML($html, true, false, true, false, '');

// Force download the PDF
$pdf->Output('payment_receipt.pdf', 'D');
?>
