<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>RCCG DTCE ICT Portal</title>
    <link rel="icon" href="https://conventionportal.rccgjuniorchurch.org/dist/img/icon2.png">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body { font-family: 'Poppins', sans-serif; background-color: #f4f4f4; }
        .hero {
            height: 100vh;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            text-align: center;
            background: linear-gradient(135deg, #0d6efd, #6610f2);
            color: white;
            padding: 3rem;
            animation: fadeIn 1.5s ease-in-out;
        }
        .hero img {
            width: 150px;
            margin-bottom: 20px;
            animation: zoomIn 1.5s ease-in-out;
        }
        .hero h1 { font-size: 3rem; font-weight: bold; }
        .hero p { font-size: 1.25rem; margin-bottom: 1.5rem; max-width: 700px; }
        .form-container {
            max-width: 450px;
            padding: 2rem;
            border-radius: 10px;
            background: white;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.15);
            transition: transform 0.3s ease-in-out;
        }
        .form-container:hover {
            transform: scale(1.02);
        }
        .step { display: none; }
        .step.active { display: block; }
        .form-group {
            position: relative;
            margin-bottom: 1.5rem;
        }
        .form-group label {
            position: absolute;
            top: 50%;
            left: 10px;
            transform: translateY(-50%);
            background: white;
            padding: 0 5px;
            transition: all 0.3s ease-in-out;
            color: #6c757d;
        }
        .form-group input:focus + label, 
        .form-group input:not(:placeholder-shown) + label {
            top: 0;
            transform: translateY(-50%) scale(0.9);
            color: #0d6efd;
        }
        .btn-primary, .btn-secondary { border-radius: 8px; font-weight: bold; margin-top: 10px; }
        .nav-link { color: white; }
        .container { margin-top: 50px; }

        @keyframes fadeIn {
            from { opacity: 0; }
            to { opacity: 1; }
        }
        @keyframes zoomIn {
            from { transform: scale(0.8); }
            to { transform: scale(1); }
        }
    </style>
</head>
<body>
    <!-- Navigation -->
    <nav class="navbar navbar-expand-lg navbar-dark bg-dark">
        <div class="container">
            <a class="navbar-brand" href="#">
                <img src="https://conventionportal.rccgjuniorchurch.org/dist/img/dtce.png" alt="RCCG DTCE Logo" width="50">
                RCCG DTCE ICT Portal
            </a>
        </div>
    </nav>

    <!-- Landing Page -->
    <section class="hero">
        <img src="https://conventionportal.rccgjuniorchurch.org/dist/img/dtce.png" alt="DTCE Logo">
        <h1>Welcome to RCCG DTCE ICT Portal</h1>
        <p>Empowering the ICT Department with seamless access to tools, resources, and support for efficient digital transformation.</p>
        <a href="#login" class="btn btn-light btn-lg">Get Started</a>
    </section>

    <!-- Multi-Step Form -->
    <div class="container" id="login">
        <div class="form-container mx-auto">
            <h3 class="text-center">Access Your Account</h3>
            <form>
                <!-- Step 1: Email Input -->
                <div class="step active" id="step-1">
                    <div class="form-group">
                        <input type="text" id="email" class="form-control" required>
                        <label for="email">Email Address</label>
                    </div>
                    <button type="button" class="btn btn-primary w-100" onclick="nextStep(2)">Next</button>
                </div>
                
                <!-- Step 2: Password Input -->
                <div class="step" id="step-2">
                    <div class="form-group">
                        <input type="password" id="password" class="form-control" required>
                        <label for="password">Password</label>
                    </div>
                    <button type="button" class="btn btn-secondary w-100" onclick="prevStep(1)">Back</button>
                    <button type="submit" class="btn btn-primary w-100">Login</button>
                </div>
            </form>
            <div class="text-center mt-3">
                <a href="#forgot-password" onclick="showForm('forgot-password')">Forgot Password?</a> | 
                <a href="#signup" onclick="showForm('signup')">Sign Up</a>
            </div>
        </div>
    </div>

    <!-- Signup and Forgot Password Forms -->
    <div class="container" id="signup" style="display: none;">
        <div class="form-container mx-auto">
            <h3 class="text-center">Sign Up</h3>
            <form>
                <div class="form-group">
                    <input type="text" id="signup-name" class="form-control" required>
                    <label for="signup-name">Full Name</label>
                </div>
                <div class="form-group">
                    <input type="email" id="signup-email" class="form-control" required>
                    <label for="signup-email">Email Address</label>
                </div>
                <div class="form-group">
                    <input type="password" id="signup-password" class="form-control" required>
                    <label for="signup-password">Password</label>
                </div>
                <button type="submit" class="btn btn-primary w-100">Sign Up</button>
            </form>
        </div>
    </div>

    <script>
        function nextStep(step) {
            document.querySelectorAll('.step').forEach(s => s.classList.remove('active'));
            document.getElementById(`step-${step}`).classList.add('active');
        }

        function prevStep(step) {
            document.querySelectorAll('.step').forEach(s => s.classList.remove('active'));
            document.getElementById(`step-${step}`).classList.add('active');
        }

        function showForm(formId) {
            document.querySelectorAll('.container').forEach(c => c.style.display = 'none');
            document.getElementById(formId).style.display = 'block';
        }
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
