<?php
session_start();
require 'conn.php';

$coordinator = null;
$phone = '';
$error = '';

// Step 1: Verify Phone Number
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['verify_phone'])) {
    $phone = trim($_POST['phone']);

    if (!empty($phone)) {
        // Fetch zone details using phone number
        $stmt = $conn->prepare("SELECT * FROM zone WHERE phone = ?");
        $stmt->execute([$phone]);
        $coordinator = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$coordinator) {
            $error = "This account has been deleted and cannot be accessed!";
        } elseif ($coordinator['status'] == 'inactive') {
            $error = "This account is inactive. Contact the administrator!";
        }
    } else {
        $error = "Please enter your phone number!";
    }
}

// Step 2: Authenticate User (with Password Verification)
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['login'])) {
    $phone = trim($_POST['hidden_phone']);
    $password = trim($_POST['password']); // Get input password

    if (!empty($phone) && !empty($password)) {
        // Fetch zone details again
        $stmt = $conn->prepare("SELECT * FROM zone WHERE phone = ?");
        $stmt->execute([$phone]);
        $coordinator = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$coordinator) {
            $error = "This account has been deleted and cannot be accessed!";
        } elseif ($coordinator['status'] == 'inactive') {
            $error = "This account is inactive. Contact the administrator!";
        } elseif ($password === $coordinator['password']) {
            // ✅ Set session variables
            $_SESSION['name'] = $coordinator['name'];
            $_SESSION['zone'] = $coordinator['zone'];
            $_SESSION['email'] = $coordinator['email'];

            // ✅ Check if password was changed
            if ($coordinator['password_changed'] == 0) {
                $_SESSION['freshLogin'] = true; // Force password change only if it's the first login
                header("Location: change-password.php");
                exit();
            } else {
                $_SESSION['freshLogin'] = false;
                header("Location: main.php");
                exit();
            }
        } else {
            $error = "Incorrect password!";
        }
    } else {
        $error = "Please enter both phone number and password!";
    }
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RCCG DTCE - Zonal Coordinator Portal</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <style>
      /* Ensure the body background is clean */
body {
    transition: background 0.3s, color 0.3s;
    background-color: #f8f9fa; /* Light background */
    overflow-x: hidden; /* Prevent horizontal scroll */
    position: relative;
}

/* Watermark container */
.watermark-container {
    position: relative;
}

/* Multiple watermarks using pseudo-elements */
.watermark-container::before,
.watermark-container::after {
    content: "";
    position: fixed; /* Ensures no extra space is taken */
    width: 250px; /* Adjust size */
    height: 250px; /* Adjust size */
    background: url('./dist/img/icon.png') no-repeat center/contain;
    opacity: 0.08; /* Adjust transparency */
    z-index: -1; /* Keeps it behind content */
    pointer-events: none; /* Prevent interaction */
}

/* Bottom-right watermark */
.watermark-container::before {
    bottom: 10%;
    right: 10%;
}

/* Top-left watermark */
.watermark-container::after {
    top: 10%;
    left: 10%;
}

/* Additional watermarks for repeated effect */
.watermark-container .watermark {
    position: fixed;
    width: 250px;
    height: 250px;
    background: url('./dist/img/icon.png') no-repeat center/contain;
    opacity: 0.08;
    z-index: -1;
    pointer-events: none;
}

/* Middle of the page */
.watermark-container .watermark.middle {
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
}

/* Top-right */
.watermark-container .watermark.top-right {
    top: 5%;
    right: 5%;
}

/* Bottom-left */
.watermark-container .watermark.bottom-left {
    bottom: 5%;
    left: 5%;
}

        /* Ensure cards stay on top of the watermark */
        .card {
            position: relative;
            z-index: 1;
        }


        .dark-mode {
            background-color: #121212;
            color: #ffffff;
        }

        .login-container {
            min-height: 100vh;
        }

        .card {
            border-radius: 10px;
        }

        .btn-primary {
            background-color: #007bff;
            border-color: #007bff;
        }

        .btn-primary:hover {
            background-color: #0056b3;
            border-color: #0056b3;
        }

        .footer {
            text-align: center;
            padding: 10px;
            font-size: 14px;
            color: white;
            background: #007bff;
            position: fixed;
            bottom: 0;
            width: 100%;
        }

       /* Ensure the dark mode button is positioned correctly */
.dark-toggle {
    position: fixed;
    top: 10px;
    right: 10px;
    z-index: 1050; /* Higher than other elements */
}

/* Fix the issue of card covering the footer on mobile */
@media (max-width: 768px) {
    .login-container {
        margin-bottom: 100px; /* Provide enough space for the footer */
    }
}


        .dark-mode .card {
            background-color: #000 !important;
            /* Black background */
            color: #fff !important;
            /* White text */
        }

        .dark-mode .card-body {
            color: #fff !important;
            /* Ensures text inside is also white */
        }
    </style>
</head>

<body>
 <!-- Dark Mode Toggle Button -->
 <button class="btn btn-primary dark-toggle" id="toggleDarkMode">
        <i class="fas fa-moon"></i> Dark Mode
    </button>

<div class="watermark-container">
    <!-- Additional watermarks -->
    <div class="watermark middle"></div>
    <div class="watermark top-right"></div>
    <div class="watermark bottom-left"></div>
</div>

    

<div class="container d-flex align-items-center justify-content-center login-container">
<div class="row w-100">
            <!-- Left Side: Instructions & Features -->
            <div class="col-md-7">
                <div class="card shadow-lg p-4">
                    <h4 class="text-center"><i class="fas fa-user-lock"></i> Welcome to the RCCG DTCE Portal</h4>
                    <hr>

                    <!-- Login Instructions -->
                    <h5><i class="fas fa-info-circle"></i> Login Instructions</h5>
                    <ul>
                        <li><i class="fas fa-key"></i> Enter your phone number and verify before logging in.</li>
                        <li><i class="fas fa-lock"></i> If you forget your password, contact the admin for assistance.</li>
                        <li><i class="fas fa-exclamation-triangle"></i> You must change your password upon first login to access portal features.</li>

                    </ul>

                    <hr>

                    <!-- Portal Features -->
                    <h5><i class="fas fa-tools"></i> Portal Features</h5>
                    <ul class="list-unstyled">
                        <li><i class="fas fa-user-shield text-primary"></i> <strong>SSO Login:</strong> Secure single sign-on for easy access.</li>
                        <li><i class="fas fa-moon text-secondary"></i> <strong>Dark Mode:</strong> Toggle between light and dark themes for a comfortable viewing experience.</li>
                        <li><i class="fas fa-bell text-warning"></i> <strong>Notifications:</strong> Stay updated with real-time alerts and messages.</li>
                        <li><i class="fas fa-chart-bar text-success"></i> <strong>General Reports:</strong> View comprehensive reports on convention, quiz, choir, and sports registrations.</li>
                        <li><i class="fas fa-file-invoice-dollar text-info"></i> <strong>Transaction Reports:</strong> Track financial transactions across all regions.</li>
                        <li><i class="fas fa-video text-danger"></i> <strong>Join Meetings:</strong> Participate in virtual meetings directly from the portal.</li>
                        <li><i class="fas fa-newspaper text-primary"></i> <strong>News & Updates:</strong> Get the latest updates on events and activities.</li>
                    </ul>
                </div>
            </div>

            <!-- Right Side: Login Form -->
            <div class="col-md-5 mt-3">
                <div class="card shadow-lg p-4">
                    <!-- Centered Logo -->
                    <img src="./dist/img/dtce.png" alt="RCCG DTCE Logo" class="img-fluid mb-3 mx-auto d-block" style="max-width: 100px;">
                    <h4><i class="fas fa-user-lock"></i> RCCG DTCE - Zonal Coordinator Portal</h4>

                    <!-- Error Message Display -->
                    <?php if (!empty($error)): ?>
                        <div id="error-message" class="error-alert">
                            <?= $error ?>
                            <span class="close-btn" onclick="closeErrorMessage()">&times;</span>
                        </div>

                        <script>
                            // Function to close the error message
                            function closeErrorMessage() {
                                document.getElementById('error-message').style.display = 'none';
                            }

                            // Auto-hide the alert after 5 seconds
                            setTimeout(closeErrorMessage, 5000);
                        </script>

                        <style>
                            .error-alert {
                                background-color: #f44336;
                                /* Red background */
                                color: white;
                                padding: 10px 20px;
                                margin: 10px 0;
                                border-radius: 5px;
                                position: relative;
                                font-size: 16px;
                                max-width: 500px;
                                display: flex;
                                justify-content: space-between;
                                align-items: center;
                            }

                            .close-btn {
                                font-size: 20px;
                                cursor: pointer;
                                margin-left: 10px;
                            }
                        </style>
                    <?php endif; ?>

                    <!-- Step 1: Phone Number Verification Form -->
                    <?php if (!$coordinator): ?>
                        <form action="index.php" method="POST">
                        <div class="mb-3 form-group">
    <input type="text" class="form-control" id="phone" name="phone" required value="<?= htmlspecialchars($phone) ?>" placeholder=" ">
    <label for="phone">Enter Phone Number</label>
</div>
<button type="submit" class="btn btn-primary mt-2 w-100" name="verify_phone">Verify</button>

<style>
    .form-group {
        position: relative;
    }

    .form-group label {
        position: absolute;
        top: 50%;
        left: 10px;
        transform: translateY(-50%);
        background: white;
        padding: 0 5px;
        transition: all 0.3s ease-in-out;
        color: #6c757d;
    }

    .form-group input:focus + label, 
    .form-group input:not(:placeholder-shown) + label {
        top: 0;
        transform: translateY(-50%) scale(0.9);
        color: #0d6efd;
    }
</style>

                        </form>
                    <?php endif; ?>

                    <!-- Step 2: Password Login Form (Appears After Verification) -->
                    <?php if ($coordinator): ?>
                        <div>
                            <div class="mb-3">
                                <label class="form-label">Coordinator's Name</label>
                                <input type="text" class="form-control" value="<?= htmlspecialchars($coordinator['name']) ?>" readonly>
                            </div>
                            <div class="mb-3">
                                <label class="form-label">Coordinator's Zone</label>
                                <input type="text" class="form-control" value="<?= htmlspecialchars($coordinator['zone']) ?>" readonly>
                            </div>
                            <div class="mb-3">
                                <label class="form-label">Coordinator's Email</label>
                                <input type="text" class="form-control" value="<?= htmlspecialchars($coordinator['email']) ?>" readonly>
                            </div>

                            <form action="index.php" method="POST">
                                <input type="hidden" name="hidden_phone" value="<?= htmlspecialchars($coordinator['phone']) ?>">

                                <div class="mb-3">
                                    <label for="password" class="form-label">Enter Password</label>
                                    <div class="input-group">
                                        <input type="password" class="form-control" id="password" name="password" required>
                                        <div class="input-group-append">
                                            <button type="button" class="btn btn-outline-secondary" id="togglePassword">
                                                <i class="fas fa-eye"></i>
                                            </button>
                                        </div>
                                    </div>
                                </div>
                                <button type="submit" class="btn btn-primary w-100" name="login">Login</button>
                            </form>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
                    




    <script>
        document.getElementById("togglePassword").addEventListener("click", function() {
            let passwordField = document.getElementById("password");
            let icon = this.querySelector("i");

            if (passwordField.type === "password") {
                passwordField.type = "text";
                icon.classList.remove("fa-eye");
                icon.classList.add("fa-eye-slash");
            } else {
                passwordField.type = "password";
                icon.classList.remove("fa-eye-slash");
                icon.classList.add("fa-eye");
            }
        });
    </script>


    <?php
    // Fetch footer content from database
    $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
    $footer = $stmt->fetch(PDO::FETCH_ASSOC);
    $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
    $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
    ?>
    <footer class="footer text-sm">
        <div class="text-xs">
            <?= $copyrightMessage ?>
            <div class="float-right d-none d-sm-inline-block">
                <b><?= $eventInfo ?></b>
            </div>
        </div>
    </footer>
    <script defer src="scripts/cookies/cookieconsent.js"></script>
    <script defer src="scripts/cookies/cookieconsent-init.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
    const toggleButton = document.getElementById('toggleDarkMode') || document.getElementById('theme-toggle');
    const icon = document.getElementById('theme-icon');

    function applyDarkMode() {
        document.body.classList.add('dark-mode');
        document.body.classList.remove('light-mode');
        if (icon) {
            icon.classList.remove('fa-sun');
            icon.classList.add('fa-moon');
        }
        localStorage.setItem('theme', 'dark');
    }

    function applyLightMode() {
        document.body.classList.add('light-mode');
        document.body.classList.remove('dark-mode');
        if (icon) {
            icon.classList.remove('fa-moon');
            icon.classList.add('fa-sun');
        }
        localStorage.setItem('theme', 'light');
    }

    // Check and apply the saved theme
    if (localStorage.getItem('theme') === 'dark') {
        applyDarkMode();
    } else {
        applyLightMode();
    }

    // Toggle event listener
    if (toggleButton) {
        toggleButton.addEventListener('click', function() {
            if (document.body.classList.contains('dark-mode')) {
                applyLightMode();
            } else {
                applyDarkMode();
            }
        });
    }
});

    </script>

</body>

</html>