<?php
session_start(); // Start the session

// Include your database connection file
require_once('conn.php');

// Check if the user is logged in and has the required session variables
if (!isset($_SESSION['name']) || !isset($_SESSION['zone']) || !isset($_SESSION['email'])) {
    header("Location: index.php"); // Redirect to login if not authenticated
    exit();
}

// Get logged-in coordinator details
$coordinator_name = $_SESSION['name'];
$coordinator_zone = $_SESSION['zone'];
$coordinator_email = $_SESSION['email'];

$freshLogin = isset($_SESSION['freshLogin']) && $_SESSION['freshLogin']; // Check if fresh login
$zone = $_SESSION['zone']; // Get the zone from the session
$currentYear = date('Y'); // Get the current year



// Check if it's a fresh login
if (isset($_SESSION['freshLogin']) && $_SESSION['freshLogin']) {
    header("Location: change-password.php");
    exit();
}

// 🔹 Function to Fetch Data Safely (Prevents NULL Issues)
function fetchData($conn, $query, $params)
{
    try {
        $stmt = $conn->prepare($query);
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }
        $stmt->execute();
        $data = $stmt->fetch(PDO::FETCH_ASSOC);

        // 🔹 If no data found, return default zero values
        return ($data !== false) ? $data : array_fill_keys(array_keys($params), 0);
    } catch (Exception $e) {
        echo "SQL Error: " . $e->getMessage();
        return array();
    }
}


// 🔹 Query for Children Category
$query_children = "
    SELECT 
        COALESCE(SUM(children1), 0) AS total_children1,
        COALESCE(SUM(children2), 0) AS total_children2,
        COALESCE(SUM(children3), 0) AS total_children3
    FROM children
    WHERE zone = :zone 
          AND year = :currentYear
          AND password IN (SELECT rrr FROM bank WHERE status = 'Approved')
";
$children_data = fetchData($conn, $query_children, [':zone' => $zone, ':currentYear' => $currentYear]);

// 🔹 Query for Teens Category
$query_teens = "
    SELECT 
        COALESCE(SUM(teens1), 0) AS total_teens1,
        COALESCE(SUM(teens2), 0) AS total_teens2
    FROM teens
    WHERE zone = :zone 
          AND year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = teens.password 
              AND bank.status = 'Approved'
          )
";
$teens_data = fetchData($conn, $query_teens, [':zone' => $zone, ':currentYear' => $currentYear]);

// 🔹 Query for Teachers Category
$query_teachers = "
    SELECT COALESCE(COUNT(*), 0) AS total_teachers
    FROM teachers
    WHERE zone = :zone 
          AND year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = teachers.password 
              AND bank.status = 'Approved'
          )
";
$teachers_data = fetchData($conn, $query_teachers, [':zone' => $zone, ':currentYear' => $currentYear]);

// 🔹 Query for Pending Registrations
$query_pending = "
    SELECT COALESCE(COUNT(*), 0) AS total_pending
    FROM bank
    WHERE zone = :zone 
          AND status = 'Pending'
          AND year = :currentYear
";
$pending_data = fetchData($conn, $query_pending, [':zone' => $zone, ':currentYear' => $currentYear]);

// 🔹 Query for Approved Registrations
$query_approved = "
    SELECT COALESCE(COUNT(*), 0) AS total_approved
    FROM bank
    WHERE zone = :zone 
          AND status = 'Approved'
          AND year = :currentYear
";
$approved_data = fetchData($conn, $query_approved, [':zone' => $zone, ':currentYear' => $currentYear]);



?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RCCG DTCE | Co-ordinator's Dashboard</title>

    <!-- RCCG Branding Colors -->

    <!-- CSS & JS Dependencies -->
    <!-- Dependencies -->
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="dist/css/custom.css">
    <link rel="stylesheet" href="newstyle.css">
    <link rel="stylesheet" href="dist/css/login_style.css">
    <link rel="stylesheet" href="assets/css/mystyle.css">
    <link rel="stylesheet" href="dist/css/animate.min.css">
    <link href="plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">


    <!-- Include ApexCharts CSS -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.css">
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">


    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>

</head>

<body class="hold-transition sidebar-mini layout-fixed">


    <!-- /.navbar -->
    <div class="wrapper">
        <!-- Navbar -->
        <nav class="main-header navbar navbar-expand-lg navbar-light">
            <div class="container-fluid">
                <!-- Navbar Toggler for Mobile -->
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
                    aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <!-- Left Navbar Links -->
                <a href="#" class="navbar-brand">
                    <img src="./dist/img/dtce.png" alt="Logo" style="height: 40px;">
                </a>

                <?php
                include 'conn.php';
                $zone = $_SESSION['zone']; // Get the province name from the session

                // Fetch the count of unread notifications for this province
                $stmt = $conn->prepare("SELECT COUNT(*) as count FROM zonenotifications WHERE zone = :zone AND is_read = 0");
                $stmt->bindValue(':zone', $zone);
                $stmt->execute();
                $count = $stmt->fetch(PDO::FETCH_ASSOC)['count'];
                ?>

                <div class="collapse navbar-collapse" id="navbarNav">
                    <ul class="navbar-nav">
                        <li class="nav-item">
                            <a class="nav-link" data-widget="pushmenu" href="#" role="button">
                                <i class="fas fa-bars"></i>
                            </a>
                        </li>
                    </ul>

                    <!-- Centered Search Form -->
                    <form class="form-inline mx-auto">
                        <input class="form-control mr-sm-2" type="search" placeholder="Search" aria-label="Search">
                        <button class="btn btn-outline-primary my-2 my-sm-0" type="submit">
                            <i class="fas fa-search"></i>
                        </button>
                    </form>

                    <!-- Right Navbar Links -->
                    <ul class="navbar-nav ml-auto">
                        <li class="nav-item">
                            <a class="nav-link" href="#">
                                <img src="./dist/img/ng3.webp" alt="Flag" style="width: 35px;">
                            </a>
                        </li>

                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle" href="#" id="notificationDropdown" role="button"
                                data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                <i class="fas fa-bell">
                                    <span class="badge badge-danger"><?php echo $count; ?></span>
                                </i>
                            </a>
                            <div class="dropdown-menu dropdown-menu-right" aria-labelledby="notificationDropdown"
                                id="notificationList">

                            </div>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="#" id="theme-toggle">
                                <i id="theme-icon" class="fas fa-sun"></i> <!-- Default icon is sun -->
                            </a>
                        </li>

                        <li class="nav-item dropdown">
                            <a class="nav-link d-flex align-items-center dropdown-toggle" data-toggle="dropdown" href="#">
                                <?php
                                // Get the session zone
                                $zone = $_SESSION["zone"];

                                // Ensure it follows the correct format: "Zone X – Region Name"
                                $zone_parts = explode(" ", $zone);

                                // Ensure there are enough parts
                                if (count($zone_parts) >= 4) {
                                    $zone_number = $zone_parts[1]; // Extracts "1" from "Zone 1"

                                    // Handle cases with multiple dashes (e.g., "Zone 3 – South – South Regions")
                                    $region_name = "";
                                    for ($i = 3; $i < count($zone_parts); $i++) {
                                        if ($zone_parts[$i] !== "–") {
                                            $region_name .= substr($zone_parts[$i], 0, 1); // Take first letter of each word
                                        }
                                    }

                                    // Format the result as "ZN X-XX"
                                    $formatted_zone = "ZN $zone_number-$region_name";
                                } else {
                                    $formatted_zone = "ZN -"; // Fallback for incorrect formats
                                }

                                // Display the formatted zone name with profile image
                                echo '<div class="province-initials d-flex align-items-center" 
                                style="background-color:rgb(6, 24, 83); color: white; padding: 8px 12px; border-radius: 50px; display: flex; align-items: center; font-weight: bold; font-size: 16px; min-width: 100px;">
                                    <img src="dist/img/icon.png" alt="Profile" style="width: 35px; height: 35px; border-radius: 50%; margin-right: 8px;">
                                    ' . $formatted_zone . '
                                </div>';
                                ?>


                                <div style="display: flex; flex-direction: column; color: white;">
                                    <span class="d-none d-md-inline"><?php echo strtoupper($_SESSION["name"]) ?></span>
                                    <small style="color: white;"><?php echo $_SESSION["zone"] ?></small>
                                </div>

                            </a>
                            <div class="dropdown-menu dropdown-menu-lg dropdown-menu-right">
                                <a href="#" class="dropdown-item"><i class="fas fa-user"></i> My Profile</a>
                                <a href="#" class="dropdown-item"><i class="fas fa-cog"></i> Settings</a>
                                <div class="dropdown-divider"></div>
                                <a href="logout.php" class="dropdown-item"><i class="fas fa-sign-out-alt"></i> Logout</a>
                            </div>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
    </div>

    <!-- Scripts -->


    <!-- /.navbar -->

    <?php
    include 'conn.php'; // Ensure this file correctly sets up $conn

    // Fetch menu items, ordered by the 'order' field
    try {
        $stmt = $conn->query("SELECT * FROM navbars WHERE status = 'active' ORDER BY `order` ASC");
        $menuItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (!$menuItems) {
            $menuItems = []; // Set to an empty array to prevent null issues
        }
    } catch (PDOException $e) {
        die("Database Error: " . $e->getMessage()); // Display error for debugging
    }

    ?>
    <!-- Main Sidebar Container -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">

        <!-- Sidebar -->
        <div class="sidebar">
            <div class="user-panel mt-3 pb-3 mb-3 d-flex align-items-center">
                <div class="image">
                    <img src="./dist/img/icon.png" alt="User Image">
                </div>
                <div class="info">
                    <a href="#" class="company-name" style="color:aliceblue">RCCG DTCE</a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">





                    <li class="nav-item">
                        <a href="main.php" class="nav-link">
                            <i class="nav-icon fas fa-chart-pie" style="color: white;"></i>
                            <p style="color: white;">Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="zonepayments.php" class="nav-link">
                            <i class="nav-icon fas fa-money-bill-wave" style="color: white !important;"></i>
                            <p style="color: white;">Payments</p>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="quiz.php" class="nav-link">
                            <i class="nav-icon fas fa-file-alt" style="color: white;"></i>
                            <p style="color: white;">Quiz Report</p>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="sport.php" class="nav-link">
                            <i class="nav-icon fas fa-running" style="color: white;"></i>
                            <p style="color: white;">Sport Report</p>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="choir.php" class="nav-link">
                            <i class="nav-icon fas fa-microphone" style="color: white;"></i>
                            <p style="color: white;">Choir Report</p>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="zoneregions.php" class="nav-link">
                            <i class="nav-icon fas fa-globe" style="color: white;"></i>
                            <p style="color: white;">Regions Details</p>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="zoneprovinces.php" class="nav-link">
                            <i class="nav-icon fas fa-map-marker-alt" style="color: white;"></i>
                            <p style="color: white;">Provinces Details</p>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="settings.php" class="nav-link">
                            <i class="nav-icon fas fa-cog" style="color: white !important;"></i>

                            <p style="color: white;">Settings</p>
                        </a>
                    </li>
                    <div class="nav-item has-treeview">
                        <a href="#" class="nav-link" data-toggle="collapse" data-target="#provincialMenu">
                            <i class="nav-icon fas fa-users-cog"></i>
                            <p class="menu-text">Provincial Coord Menus <i class="right fas fa-angle-left"></i></p>
                        </a>

                        <ul id="provincialMenu" class="nav nav-treeview collapse">
                            <?php foreach ($menuItems as $item): ?>
                                <li class="nav-item">
                                    <a href="#" class="nav-link" style="pointer-events: none; opacity: 0.5; cursor: default;">
                                        <i class="nav-icon fas <?php echo htmlspecialchars($item['icon']); ?>"></i>
                                        <p><?php echo htmlspecialchars($item['name']); ?></p>
                                    </a>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div>

                    <script>
                        document.addEventListener("DOMContentLoaded", function() {
                            const sidebar = document.querySelector(".main-sidebar");
                            const menuText = document.querySelectorAll(".menu-text");

                            function toggleMenuText() {
                                if (sidebar.classList.contains("sidebar-collapse")) {
                                    menuText.forEach(text => text.style.display = "none");
                                } else {
                                    menuText.forEach(text => text.style.display = "inline");
                                }
                            }

                            toggleMenuText();
                            document.body.addEventListener("classChange", toggleMenuText);
                        });
                    </script>

        </div>
        </div>
        </div>

        <script>
            function showMessage() {
                alert("This menu is for Provincial Coordinators only.");
            }
        </script>





        </ul>


    </aside>



    <!-- Content Wrapper -->

    <div class="content-wrapper">
        <div class="breadcrumb-wrapper">
            <ul class="breadcrumb">
                <li class="breadcrumb-item"><a href="./main.php">HOME</a></li>
                <li class="breadcrumb-item active">Dashboard</li>
            </ul>
        </div>
        <?php include("news.php"); ?>
        <?php
        include 'conn.php';

        // Fetch the cover picture
        $stmt = $conn->query("SELECT * FROM cover_pic ORDER BY id DESC LIMIT 1");
        $coverPic = $stmt->fetch(PDO::FETCH_ASSOC);

        $imagePath = $coverPic ? $coverPic['image_path'] : './dist/img/bg-login.jpg'; // Default image if none found
        ?>

        <div class="row">
            <div class="col-sm-12">
                <div class="profile-bg-picture"
                    style="background-image: url('<?php echo htmlspecialchars($imagePath); ?>');">
                    <div class="picture-bg-overlay"></div>
                </div>
            </div>
        </div>
        <h2 class="text-center text-bold mt-3">Welcome to <?php echo htmlspecialchars($_SESSION['zone']); ?> Dashboard</h2>

        <!-- Row for Chart & Summary Card -->
        <div class="row">
            <!-- Chart Section (Larger: 8 Columns) -->
            <div class="col-lg-8 col-12 mb-4">
                <div class="card shadow-lg rounded h-100">
                    <div class="card-header bg-primary text-white d-flex align-items-center">
                        <i class="fas fa-chart-bar me-3"></i>
                        <h5 class="header-title mb-0" style="color: white !important;"><?php echo htmlspecialchars(strtoupper($_SESSION['zone'])); ?>
                            CONVENTION REGISTRATION ANALYSIS (APPROVED REGISTRATIONS)</h5>
                    </div>
                    <div class="card-body">
                        <div id="chart" style="width: 100%; height: 400px;"></div>
                        <div id="chart-data" class="mt-3"></div>
                    </div>
                </div>
            </div>

            <!-- ✅ Summary Card (Smaller: 4 Columns) -->
            <?php
            // Start session


            // Get the session zone
            $session_zone = $_SESSION['zone'] ?? '';

            // Fetch all regions under the session (zone)
            $query = "SELECT region, 
                 SUM(CASE WHEN status = 'Approved' THEN 1 ELSE 0 END) AS approved_registrations, 
                 SUM(CASE WHEN status = 'Pending' THEN 1 ELSE 0 END) AS pending_registrations 
          FROM bank 
          WHERE zone = :zone
          GROUP BY region";

            $stmt = $conn->prepare($query);
            $stmt->execute(['zone' => $session_zone]);
            $zones = $stmt->fetchAll(PDO::FETCH_ASSOC);
            ?>

            <!-- Summary Report Card -->
            <div class="col-lg-4 col-12 mb-4">
                <div class="card shadow-lg rounded h-100">
                    <div class="card-header bg-success text-white d-flex align-items-center">
                        <i class="fas fa-info-circle me-2"></i> <!-- Info Icon -->
                        <h5 class="card-title mb-0">Summary Report</h5>
                    </div>
                    <div class="card-body text-center">
                        <h4>Approved & Pending Registrations</h4>
                        <p>Latest updates for your zone: <strong><?= htmlspecialchars($session_zone); ?></strong></p>

                        <!-- Display first 2 regions -->
                        <div id="regionContainer">
                            <?php if (!empty($zones)): ?>
                                <?php foreach ($zones as $index => $zone): ?>
                                    <div class="region-card p-3 border rounded bg-light <?= $index >= 2 ? 'd-none' : '' ?>">
                                        <h5 class="fw-bold text-uppercase">
                                            <?= is_numeric($zone['region']) ? "Region {$zone['region']}" : $zone['region']; ?>
                                        </h5>
                                        <div class="row">
                                            <div class="col-6">
                                                <div class="card border-success">
                                                    <div class="card-body">
                                                        <i class="fas fa-check-circle fa-2x text-success"></i>
                                                        <h6>Approved</h6>
                                                        <h4><?= $zone['approved_registrations']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-6">
                                                <div class="card border-warning">
                                                    <div class="card-body">
                                                        <i class="fas fa-clock fa-2x text-warning"></i>
                                                        <h6>Pending</h6>
                                                        <h4><?= $zone['pending_registrations']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <p>No registrations found for this zone.</p>
                            <?php endif; ?>
                        </div>

                        <!-- View More Button -->
                        <?php if (count($zones) > 2): ?>
                            <button id="viewMoreBtn" class="btn btn-outline-success mt-3">View More</button>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <!-- Bootstrap Modal for More Regions -->
            <div class="modal fade" id="regionsModal" tabindex="-1" aria-labelledby="regionsModalLabel" aria-hidden="true">
                <div class="modal-dialog modal-lg">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="regionsModalLabel">Summary Report for other Regions</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                        </div>
                        <div class="modal-body" id="modalBody">
                            <!-- More regions will be loaded here -->
                        </div>
                    </div>
                </div>
            </div>




            <!-- Modal for More Regions -->
            <div class="modal fade" id="regionModal" tabindex="-1" aria-labelledby="regionModalLabel" aria-hidden="true">
                <div class="modal-dialog modal-lg">
                    <div class="modal-content">
                        <div class="modal-header bg-success text-white">
                            <h5 class="modal-title" id="regionModalLabel">All Regions in <?= htmlspecialchars($session_zone); ?></h5>
                            <button type="button" class="btn text-white" data-bs-dismiss="modal">
                                <i class="fas fa-times"></i>
                            </button>

                        </div>
                        <div class="modal-body">
                            <div class="row">
                                <?php foreach ($zones as $zone): ?>
                                    <div class="col-md-6 mb-3">
                                        <div class="card border-info">
                                            <div class="card-body text-center">
                                                <h5 class="fw-bold text-uppercase">
                                                    <?= is_numeric($zone['region']) ? "Region {$zone['region']}" : $zone['region']; ?>
                                                </h5>
                                                <div class="row">
                                                    <div class="col-6">
                                                        <div class="card border-success">
                                                            <div class="card-body">
                                                                <i class="fas fa-check-circle fa-2x text-success"></i>
                                                                <h6>Approved</h6>
                                                                <h4><?= $zone['approved_registrations']; ?></h4>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="col-6">
                                                        <div class="card border-warning">
                                                            <div class="card-body">
                                                                <i class="fas fa-clock fa-2x text-warning"></i>
                                                                <h6>Pending</h6>
                                                                <h4><?= $zone['pending_registrations']; ?></h4>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        </div>
                    </div>
                </div>
            </div>


        </div>

        <?php
        require 'conn.php';

        $zone = $_SESSION['zone'];

        // Query to fetch all required registration data grouped by region
        $query = "
    SELECT r.region,
        SUM(r.p1) AS booked_children, SUM(r.p1c) AS registered_children,
        SUM(r.p2) AS booked_teens, SUM(r.p2c) AS registered_teens,
        SUM(r.p3) AS booked_teachers, SUM(r.p3c) AS registered_teachers,
        COALESCE(SUM(b.cash), 0) AS total_cash_paid  -- ✅ Fetching cash from bank table
    FROM registration r
    LEFT JOIN bank b ON r.password = b.rrr  -- ✅ Linking bank and registration using rrr = password
    WHERE r.zone = :zone
    GROUP BY r.region";
        $stmt = $conn->prepare($query);
        $stmt->execute(['zone' => $zone]);
        $registrations = $stmt->fetchAll(PDO::FETCH_ASSOC);


        ?>
        <section class="helpful-tools">
            <div class="container mt-3">
                <div class="col-12">
                    <div class="section-title">
                        <h3>DTCE <span class="alternate">Help Tools</span></h3>
                        <p>Navigate through your dashboard with the following help tools</p>
                    </div>
                </div>

                <!-- HELPFUL TOOLS ROW -->
                <div class="row">
                    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
                    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">

                    <div class="container mt-4">
                        <div class="row">
                            <!-- Quiz Report -->
                            <div class="col-md-3 mb-4">
                                <a href="quiz.php" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-journal-text"></i></div>
                                        <h6 class="card-title">Quiz Report</h6>
                                        <p class="card-subtitle">Track quiz results</p>
                                    </div>
                                </a>
                            </div>

                            <!-- Sport Report -->
                            <div class="col-md-3 mb-4">
                                <a href="sport.php" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-trophy-fill"></i></div>
                                        <h6 class="card-title">Sport Report</h6>
                                        <p class="card-subtitle">Monitor sports activities</p>
                                    </div>
                                </a>
                            </div>

                            <!-- Helpful Tool -->
                            <div class="col-md-3 mb-4">
                                <a href="#" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-lightbulb-fill"></i></div>
                                        <h6 class="card-title">Helpful Tool</h6>
                                        <p class="card-subtitle">Enhance your workflow</p>
                                    </div>
                                </a>
                            </div>

                            <!-- Choir Report -->
                            <div class="col-md-3 mb-4">
                                <a href="choir.php" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-music-note-beamed"></i></div>
                                        <h6 class="card-title">Choir Report</h6>
                                        <p class="card-subtitle">Track choir performance</p>
                                    </div>
                                </a>
                            </div>

                            <!-- Support Ticket -->
                            <div class="col-md-3 mb-4">
                                <a href="#" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-envelope-fill"></i></div>
                                        <h6 class="card-title" style="white-space: nowrap;">Support Ticket</h6>
                                        <p class="card-subtitle" style="white-space: nowrap;">Manage support requests</p>
                                    </div>
                                </a>
                            </div>


                            <!-- FAQs -->
                            <div class="col-md-3 mb-4">
                                <a href="zoneprovinces.php" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-geo-alt-fill"></i></div> <!-- Location icon for Province -->
                                        <h6 class="card-title text-nowrap">Provinces Info</h6>
                                        <p class="card-subtitle text-nowrap">All Provinces Details</p>
                                    </div>
                                </a>
                            </div>

                            <!-- Other Report -->
                            <div class="col-md-3 mb-4">
                                <a href="zoneregions.php" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-globe"></i></div> <!-- Globe icon for Region -->
                                        <h6 class="card-title text-nowrap">Regions Info</h6>
                                        <p class="card-subtitle text-nowrap">All Regions Details</p>
                                    </div>
                                </a>
                            </div>


                            <!-- Other Report -->
                            <div class="col-md-3 mb-4">
                                <a href="zonequiz.php" class="text-decoration-none">
                                    <div class="card helpful-tool-box text-center p-3 shadow-sm">
                                        <div class="icon-box"><i class="bi bi-person-badge"></i></div>
                                        <h6 class="card-title" style="white-space: nowrap;">Quiz Director</h6>
                                        <p class="card-subtitle" style="white-space: nowrap;">Create quiz director profile</p>
                                    </div>
                                </a>
                            </div>



                        </div>
                    </div>

                    <style>
                        /* Default Light Mode */
                        :root {
                            --card-bg: #ffffff;
                            --text-color: #000;
                            --subtitle-color: #555;
                        }

                        /* Dark Mode */
                        .dark-mode {
                            --card-bg: linear-gradient(135deg, #2a2a2a, #1e1e1e);
                            --text-color: #d1fadf;
                            --subtitle-color: #bbb;
                        }

                        /* Card Styling */
                        .helpful-tool-box {
                            border: 1px solid #ddd;
                            border-radius: 12px;
                            transition: all 0.3s ease-in-out;
                            position: relative;
                            overflow: hidden;
                            padding-top: 60px;
                            background: var(--card-bg);
                        }

                        .helpful-tool-box:hover {
                            transform: translateY(-5px);
                            box-shadow: 0 6px 15px rgba(0, 0, 0, 0.2);
                        }

                        /* Icon Styling */
                        .icon-box {
                            position: absolute;
                            top: 15px;
                            left: 50%;
                            transform: translateX(-50%);
                            background: #0d6efd;
                            padding: 12px;
                            border-radius: 50%;
                            width: 60px;
                            height: 60px;
                            display: flex;
                            align-items: center;
                            justify-content: center;
                            animation: bounce 1.5s infinite;
                            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
                        }

                        .icon-box i {
                            color: #fff;
                            font-size: 2rem;
                        }

                        /* Text Styling */
                        .card-title {
                            font-size: 16px;
                            font-weight: bold;
                            color: var(--text-color);
                            margin-top: 70px;
                            text-transform: uppercase;
                            letter-spacing: 1px;
                        }

                        .card-subtitle {
                            font-size: 14px;
                            font-weight: 500;
                            color: var(--subtitle-color);
                            margin-top: 5px;
                        }

                        /* Mobile Spacing */
                        @media (max-width: 768px) {
                            .helpful-tool-box {
                                margin-bottom: 20px;
                            }
                        }

                        /* Icon Animation */
                        @keyframes bounce {

                            0%,
                            100% {
                                transform: translateX(-50%) translateY(0);
                            }

                            50% {
                                transform: translateX(-50%) translateY(-5px);
                            }
                        }
                    </style>


        </section>

        <div class="container mt-3">
            <div class="row">
                <div class="col-12">
                    <div class="section-title">
                        <h3>DTCE <span class="alternate">Convention Analysis</span></h3>
                        <p>Stay up to date with recent analysis</p>
                    </div>
                </div>
            </div>

            <!-- Calculate Total Amount Paid Across All Regions -->
            <?php
            $totalAmountPaid = array_sum(array_column($registrations, 'cash'));
            ?>

            <style>
                /* ATM Card Styling */
                .atm-card {
                    border-radius: 15px;
                    padding: 20px;
                    color: #fff;
                    box-shadow: 0px 10px 20px rgba(0, 0, 0, 0.3);
                    position: relative;
                    overflow: hidden;
                    width: 100%;
                    max-width: 100%;
                    /* Full width */
                    height: 200px;
                    /* Flat and wide */
                    margin: auto;
                    text-align: center;
                    transition: background 0.5s ease-in-out;
                }

                /* Light Mode Background */
                .atm-card.light-mode {
                    background: linear-gradient(135deg, #0d6efd, #023e8a);
                    /* Flat Blue Gradient */
                }

                /* Dark Mode Background - Animated */
                .atm-card.dark-mode {
                    background: linear-gradient(-45deg, #ff9a9e, #fad0c4, #fad0c4, #fbc2eb, #a18cd1);
                    background-size: 400% 400%;
                    animation: gradientAnimation 5s ease infinite;
                }

                /* Animated Background for Dark Mode */
                @keyframes gradientAnimation {
                    0% {
                        background-position: 0% 50%;
                    }

                    50% {
                        background-position: 100% 50%;
                    }

                    100% {
                        background-position: 0% 50%;
                    }
                }

                /* Money Icon - Positioned at the Top */
                .money-icon {
                    font-size: 3rem;
                    margin-bottom: 5px;
                    animation: pulse 1.5s infinite alternate;
                }

                /* Card Digital Screen */
                .atm-screen {
                    background: rgba(0, 0, 0, 0.3);
                    padding: 15px;
                    border-radius: 10px;
                    margin-top: 5px;
                    font-family: 'Digital-7', monospace;
                }

                /* Embossed Text */
                .embossed-text {
                    font-weight: bold;
                    letter-spacing: 1px;
                    text-transform: uppercase;
                    text-shadow: 1px 1px 2px rgba(255, 255, 255, 0.2);
                }

                /* Glowing Effect */
                @keyframes pulse {
                    0% {
                        transform: scale(1);
                        opacity: 1;
                    }

                    100% {
                        transform: scale(1.1);
                        opacity: 0.8;
                    }
                }

                /* Responsive */
                @media (max-width: 768px) {
                    .atm-card {
                        height: 180px;
                        /* Adjust height on smaller screens */
                    }
                }
            </style>

            <!-- ATM Card -->
            <div class="atm-card light-mode" id="atmCard">
                <!-- Money Icon at the Top -->
                <div class="atm-card-body">
                    <i class="fas fa-money-bill-wave money-icon"></i>
                </div>

                <!-- ATM Display Screen -->
                <div class="atm-screen">
                    <h5 class="embossed-text">Total Amount Paid (<?php echo htmlspecialchars($_SESSION['zone']); ?>)</h5>
                    <h2 class="embossed-text">₦<?= number_format(array_sum(array_column($registrations, 'total_cash_paid')), 2); ?></h2>
                </div>
            </div>

            <!-- Toggle Dark/Light Mode -->
            <script>
                function toggleDarkMode() {
                    const card = document.getElementById("atmCard");
                    if (card.classList.contains("light-mode")) {
                        card.classList.remove("light-mode");
                        card.classList.add("dark-mode");
                    } else {
                        card.classList.remove("dark-mode");
                        card.classList.add("light-mode");
                    }
                }

                // Auto-detect dark mode preference
                if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
                    toggleDarkMode();
                }
            </script>




            <div class="container mt-3">
                <div class="row">
                    <?php foreach ($registrations as $index => $reg): ?>
                        <?php
                        // Format region name
                        $regionName = is_numeric($reg['region']) ? "Region {$reg['region']}" : $reg['region'];
                        ?>
                        <div class="col-md-3 mb-4"> <!-- ✅ Display 4 regions per row -->
                            <div class="card text-center border-dark shadow-sm">
                                <div class="card-body" id="regionCard<?= $index; ?>">
                                    <h4 class="fw-bold text-uppercase"><?= $regionName; ?></h4> <!-- ✅ Bigger Region Name -->
                                    <i class="fas fa-money-bill-wave fa-3x text-success"></i>
                                    <h5 class="mt-2">Total Amount Paid</h5>
                                    <h2 class="text-success">₦<?= number_format($reg['total_cash_paid'], 2); ?></h2>

                                    <!-- Expandable Region Details -->
                                    <button class="btn btn-primary btn-sm mt-3 toggleDetails" type="button" data-index="<?= $index; ?>">
                                        <i class="fas fa-eye"></i> View Details
                                    </button>


                                    <div class="details-section mt-3" id="regionDetails<?= $index; ?>" style="display: none;">
                                        <div class="row">
                                            <!-- Booked Children -->
                                            <div class="col-6">
                                                <div class="card text-center">
                                                    <div class="card-body">
                                                        <i class="fas fa-users fa-2x text-primary"></i>
                                                        <h6>Booked Children</h6>
                                                        <h4><?= $reg['booked_children']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>

                                            <!-- Registered Children -->
                                            <div class="col-6">
                                                <div class="card text-center">
                                                    <div class="card-body">
                                                        <i class="fas fa-user-plus fa-2x text-success"></i>
                                                        <h6>Registered Children</h6>
                                                        <h4><?= $reg['registered_children']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>

                                            <!-- Booked Teens -->
                                            <div class="col-6 mt-3">
                                                <div class="card text-center">
                                                    <div class="card-body">
                                                        <i class="fas fa-users fa-2x text-warning"></i>
                                                        <h6>Booked Teens</h6>
                                                        <h4><?= $reg['booked_teens']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>

                                            <!-- Registered Teens -->
                                            <div class="col-6 mt-3">
                                                <div class="card text-center">
                                                    <div class="card-body">
                                                        <i class="fas fa-user-check fa-2x text-info"></i>
                                                        <h6>Registered Teens</h6>
                                                        <h4><?= $reg['registered_teens']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>

                                            <!-- Booked Teachers -->
                                            <div class="col-6 mt-3">
                                                <div class="card text-center">
                                                    <div class="card-body">
                                                        <i class="fas fa-chalkboard-teacher fa-2x text-dark"></i>
                                                        <h6>Booked Teachers</h6>
                                                        <h4><?= $reg['booked_teachers']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>

                                            <!-- Registered Teachers -->
                                            <div class="col-6 mt-3">
                                                <div class="card text-center">
                                                    <div class="card-body">
                                                        <i class="fas fa-user-tie fa-2x text-primary"></i>
                                                        <h6>Registered Teachers</h6>
                                                        <h4><?= $reg['registered_teachers']; ?></h4>
                                                    </div>
                                                </div>
                                            </div>
                                        </div> <!-- End row -->
                                    </div> <!-- End details section -->
                                </div>
                            </div>
                        </div> <!-- End col-md-3 -->
                    <?php endforeach; ?>
                </div> <!-- End row -->
            </div> <!-- End container -->


            <?php
            // Include the database connection
            include 'conn.php';

            // Initialize meetings variable
            $meetings = [];

            // Fetch all meetings for display
            $stmt = $conn->prepare("SELECT * FROM meetings");
            $stmt->execute();
            $meetings = $stmt->fetchAll(PDO::FETCH_ASSOC);
            ?>

            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <div class="section-title">
                            <h3>DTCE <span class="alternate">Meetings</span></h3>
                            <p>Stay up to date with recent meetings</p>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <?php foreach ($meetings as $meeting): ?>
                        <?php
                        // Create the Zoom link for the current meeting
                        $zoom_link = "https://zoom.us/j/" . htmlspecialchars($meeting['meeting_id']);
                        ?>
                        <div class="col-md-3 mb-4">
                            <div class="card shadow-lg border-0">
                                <div class="position-relative">
                                    <a href="<?php echo $zoom_link; ?>" target="_blank">
                                        <img src="<?php echo htmlspecialchars($meeting['meeting_image']); ?>"
                                            alt="Meeting Image" class="card-img-top img-fluid rounded-top">
                                    </a>
                                    <div class="position-absolute top-0 start-0 m-2  p-1 rounded">
                                        <?php if (htmlspecialchars($meeting['status']) === 'active'): ?>
                                            <a href="<?php echo $zoom_link; ?>" target="_blank" class=" btn btn-light badge bg-primary fw-bold" style="font-size: 0.8rem; padding: 5px 10px;">
                                                Join Meeting
                                            </a>
                                        <?php else: ?>
                                            <span class="badge bg-danger">
                                                FINISHED
                                            </span>
                                        <?php endif; ?>
                                    </div>
                                </div>

                                <div class="card-body">
                                    <h5 class="card-title text-dark font-weight-bold mb-4">
                                        <?php echo htmlspecialchars($meeting['title']); ?>
                                    </h5>
                                    <div class="d-flex justify-content-between mb-2">
                                        <div class="d-flex align-items-center">
                                            <i class="fa fa-calendar text-primary me-3"></i>
                                            <span class="text-muted"><?php echo htmlspecialchars(date('M d, Y', strtotime($meeting['date']))); ?></span>
                                        </div>
                                        <div class="d-flex align-items-center">
                                            <i class="fa fa-clock text-primary me-3"></i>
                                            <span class="text-muted"><?php echo htmlspecialchars($meeting['duration']); ?></span>
                                        </div>
                                    </div>
                                    <p class="text-muted mb-3">
                                        Starting Time:
                                        <span class="text-primary font-weight-bold">
                                            <?php echo htmlspecialchars(date('g:i A', strtotime($meeting['start_time']))); ?>
                                        </span>
                                    </p>
                                    <p class="text-muted mb-3">
                                        Meeting ID: <span class="text-secondary font-weight-bold"><?php echo htmlspecialchars($meeting['meeting_id']); ?></span>
                                    </p>
                                    <div class="pt-3 border-top">
                                        <a href="instructor-details.html"
                                            class="d-flex align-items-center text-muted hover:text-primary text-decoration-none">
                                            <img class="rounded-circle me-3 organizer-img"
                                                src="<?php echo htmlspecialchars($meeting['speaker_image']); ?>"
                                                alt="Speaker">
                                            <style>
                                                .organizer-img {
                                                    width: 50px !important;
                                                    height: 50px !important;
                                                    object-fit: cover;
                                                    /* Ensures the image is properly cropped */
                                                    max-width: 100%;
                                                    /* Prevents it from growing larger */
                                                }
                                            </style>
                                            <div>
                                                <span style='text-decoration:none;'>Organizer:</span>
                                                <h6 class="mb-0 font-weight-bold text-dark" style='text-decoration:none;'>
                                                    <?php echo htmlspecialchars($meeting['speaker_name']); ?></h6>
                                            </div>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>


            <!--------DTCE VIDEOS --------->
            <!-- Upcoming Events Section---->
            <?php
            // Include your database connection
            include 'conn.php'; // This will replace the previous connection code

            try {
                // Fetch upcoming events
                $stmt = $conn->query("SELECT * FROM upcomingevents ORDER BY event_date ASC");
                $events = $stmt->fetchAll(PDO::FETCH_ASSOC);
            } catch (PDOException $e) {
                echo "Database error: " . $e->getMessage();
                die();
            }
            ?>

            <!-- For displaying events -->
            <div class="container mt-3">
                <div class="col-12">
                    <div class="section-title">
                        <h3>Upcoming <span class="alternate">Events</span></h3>
                        <p>Stay up to date with recent events and activities of DTCE</p>
                    </div>
                </div>

                <?php if (count($events) > 0): ?>
                    <?php if (count($events) > 4): ?>
                        <div id="event-carousel" class="carousel slide" data-bs-ride="carousel">
                            <div class="carousel-inner">
                                <?php foreach (array_chunk($events, 4) as $index => $eventChunk): ?>
                                    <div class="carousel-item <?php echo $index === 0 ? 'active' : ''; ?>">
                                        <div class="row g-4">
                                            <?php foreach ($eventChunk as $event): ?>
                                                <div class="col-lg-3 col-md-6">
                                                    <div class="card event-card">
                                                        <img src="<?php echo htmlspecialchars($event['event_image']); ?>"
                                                            class="card-img-top" alt="Event Banner">
                                                        <div class="card-body">
                                                            <h5 class="card-title"><?php echo htmlspecialchars($event['event_name']); ?></h5>
                                                            <p class="card-text">
                                                                <?php echo nl2br(htmlspecialchars($event['event_details'])); ?>
                                                            </p>
                                                            <a href="<?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'javascript:void(0);' : htmlspecialchars($event['event_link']); ?>"
                                                                class="btn btn-primary"
                                                                <?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'disabled' : ''; ?>>
                                                                <?php
                                                                // If the event is closed, display "Event Closed", otherwise display the original button text
                                                                echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'Event Closed' : htmlspecialchars($event['button_text']);
                                                                ?>
                                                            </a>


                                                            <div class="countdown mt-3" data-event-date="<?php echo $event['event_date']; ?>"></div>
                                                        </div>
                                                    </div>
                                                </div>
                                            <?php endforeach; ?>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>

                            <!-- Carousel Controls -->
                            <button class="carousel-control-prev" type="button" data-bs-target="#event-carousel" data-bs-slide="prev">
                                <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                                <span class="visually-hidden">Previous</span>
                            </button>
                            <button class="carousel-control-next" type="button" data-bs-target="#event-carousel" data-bs-slide="next">
                                <span class="carousel-control-next-icon" aria-hidden="true"></span>
                                <span class="visually-hidden">Next</span>
                            </button>
                        </div>
                    <?php else: ?>
                        <div class="row g-4">
                            <?php foreach ($events as $event): ?>
                                <div class="col-lg-3 col-md-6">
                                    <div class="card event-card">
                                        <img src="<?php echo htmlspecialchars($event['event_image']); ?>" class="card-img-top" alt="Event Banner">
                                        <div class="card-body">
                                            <h5 class="card-title"><?php echo htmlspecialchars($event['event_name']); ?></h5>
                                            <p class="card-text">
                                                <?php echo nl2br(htmlspecialchars($event['event_details'])); ?></p>
                                            <a href="<?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'javascript:void(0);' : htmlspecialchars($event['event_link']); ?>"
                                                class="btn btn-primary"
                                                <?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'disabled' : ''; ?>>
                                                <?php
                                                // If the event is closed, display "Event Closed", otherwise display the original button text
                                                echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'Event Closed' : htmlspecialchars($event['button_text']);
                                                ?>
                                            </a>


                                            <div class="countdown mt-3" data-event-date="<?php echo $event['event_date']; ?>"></div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                <?php else: ?>
                    <p>No upcoming events at the moment.</p>
                <?php endif; ?>
            </div>


            <?php
            include 'conn.php';

            // Fetch video details from the videos table
            $stmt = $conn->query("SELECT * FROM videos");
            $videoItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // Define default thumbnail (if needed)
            $defaultThumbnail = 'https://img.youtube.com/vi/czB6KESJLQ4/maxresdefault.jpg'; // Path to your default thumbnail

            // Debug: Output the paths being used
            // var_dump($videoItems); // Uncomment for debugging
            ?>

            <div class="container mt-4">
                <?php if (!empty($videoItems)): ?>
                    <div class="col-12 mt-">
                        <div class="section-title">
                            <h3>DTCE <span class="alternate">Videos</span></h3>
                            <p>Stay up to date with recent DTCE Videos</p>
                        </div>
                    </div>
                <?php endif; ?>

                <div class="row" id="videoContainer">

                    <?php foreach ($videoItems as $index => $item): ?>
                        <div class="col-md-4 mb-4">
                            <div class="video-card" data-id="<?php echo htmlspecialchars($item['video_id']); ?>">
                                <div class="position-relative video-wrapper">
                                    <?php
                                    $videoId = !empty($item['video_id']) ? htmlspecialchars($item['video_id']) : '';
                                    $thumbnailPath = $videoId ? "https://img.youtube.com/vi/$videoId/maxresdefault.jpg" : $defaultThumbnail;
                                    ?>
                                    <img src="<?php echo $thumbnailPath; ?>" class="img-fluid video-thumbnail" alt="<?php echo htmlspecialchars($item['title']); ?>">

                                    <!-- Play Icon Overlay -->
                                    <div class="play-icon">
                                        <i class="fa fa-play-circle"></i>
                                    </div>

                                    <!-- Hidden Video Iframe -->
                                    <iframe class="video-iframe" src="" allowfullscreen></iframe>
                                </div>
                                <div class="video-card-body">
                                    <h5 class="video-card-title"><?php echo htmlspecialchars($item['title']); ?></h5>
                                    <p class="video-card-text"><?php echo htmlspecialchars($item['description']); ?></p>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>


    </div>




    <!-- Footer -->
    <?php
    include 'conn.php'; // Ensure this file contains your database connection

    // Fetch footer content from the footer table
    $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
    $footer = $stmt->fetch(PDO::FETCH_ASSOC);
    $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
    $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
    ?>
    <footer class="main-footer text-sm">
        <div class="text-xs" id="copyright">
            <?php echo $copyrightMessage; ?>
            <div class="float-right d-none d-sm-inline-block">
                <b><?php echo $eventInfo; ?></b>
            </div>
        </div>
    </footer>
    </div>
    <?php
    include 'conn.php'; // Make sure this file contains your database connection

    // Fetch the modal content from the database
    $stmt = $conn->query("SELECT message FROM modal_content ORDER BY id DESC LIMIT 1");
    $modalContent = $stmt->fetch(PDO::FETCH_ASSOC);
    $message = $modalContent['message'];
    ?>

    <!-- Modal HTML -->
    <div id="announcementModal" class="modal">
        <div class="modal-content">
            <span class="close-btn" onclick="closeModal()">&times;</span>
            <h2> <i class="bi bi-hand-wave"></i> Welcome to the New Convention Portal! </h2>

            <p>
                <?php echo $message; ?>
            </p>
        </div>
    </div>

    <!-- Button to Trigger Toast (For Testing) -->


    <!-- Toast Container -->
    <div class="toast-container" style="position: absolute; top: 20px; right: 20px;">
        <!-- Toast HTML -->
        <div class="toast" id="myToast" role="alert" aria-live="assertive" aria-atomic="true" data-delay="3000">
            <div class="toast-header">
                <strong class="mr-auto">Welcome Message</strong>
                <small class="text-muted">just now</small>
                <button type="button" class="ml-2 mb-1 close" data-dismiss="toast" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="toast-body" id="toastBody">
                <p>Welcome back, <?php echo htmlspecialchars($_SESSION['zone'], ENT_QUOTES, 'UTF-8'); ?>! We are glad to
                    have you here.</p>
            </div>
        </div>
    </div>

    </div>
    <!-- Scripts -->
    <script src="plugins/jquery/jquery.min.js"></script>
    <script src="plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
    <script src="plugins/sweetalert2/sweetalert2.min.js"></script>
    <script src="plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
    <script src="dist/js/adminlte.min.js"></script>
    <script defer src="scripts/cookies/cookieconsent.js"></script>
    <script defer src="scripts/cookies/cookieconsent-init.js"></script>
    <script src="plugins/jquery-validation/jquery.validate.min.js"></script>
    <script src="plugins/jquery-validation/additional-methods.min.js"></script>
    <!-- Include jQuery and Bootstrap JS -->

    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>




    <script>
        document.addEventListener("DOMContentLoaded", function() {
            document.querySelectorAll(".toggleDetails").forEach(button => {
                button.addEventListener("click", function() {
                    let index = this.getAttribute("data-index");
                    let detailsSection = document.getElementById("regionDetails" + index);

                    if (detailsSection.style.display === "none") {
                        detailsSection.style.display = "block";
                        this.innerHTML = '<i class="fas fa-eye-slash"></i> Hide Details';
                    } else {
                        detailsSection.style.display = "none";
                        this.innerHTML = '<i class="fas fa-eye"></i> View Details';
                    }
                });
            });
        });
    </script>

    <script>
        document.addEventListener("DOMContentLoaded", function() {
            let viewMoreBtn = document.getElementById("viewMoreBtn");
            let modalBody = document.getElementById("modalBody");

            if (viewMoreBtn) {
                viewMoreBtn.addEventListener("click", function() {
                    // Clone all hidden regions and add them to the modal
                    let hiddenRegions = document.querySelectorAll(".region-card.d-none");
                    modalBody.innerHTML = ""; // Clear previous content

                    hiddenRegions.forEach(region => {
                        let clone = region.cloneNode(true);
                        clone.classList.remove("d-none");
                        modalBody.appendChild(clone);
                    });

                    // Open the modal
                    let myModal = new bootstrap.Modal(document.getElementById("regionsModal"));
                    myModal.show();
                });
            }
        });
    </script>


    <script>
        // Function to show the toast
        function showToast() {
            const toast = document.getElementById('myToast');
            $(toast).toast('show'); // Manually trigger the toast
        }

        // Auto-trigger the toast on page load
        window.onload = function() {
            showToast();
        };
    </script>

    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Check if the modal has been closed previously
            if (!localStorage.getItem("modalClosed")) {
                // Show the modal if not closed
                document.getElementById("announcementModal").style.display = "block";
            }
        });

        function closeModal() {
            // Hide the modal
            document.getElementById("announcementModal").style.display = "none";
            // Set a flag in localStorage to indicate that the modal has been closed
            localStorage.setItem("modalClosed", "true");
        }
    </script>
    <!-- Scripts -->





    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Fetch data from PHP (Ensure correct integer conversion)
            var children1 = <?php echo json_encode((int)$children_data['total_children1']); ?>;
            var children2 = <?php echo json_encode((int)$children_data['total_children2']); ?>;
            var children3 = <?php echo json_encode((int)$children_data['total_children3']); ?>;
            var teens1 = <?php echo json_encode((int)$teens_data['total_teens1']); ?>;
            var teens2 = <?php echo json_encode((int)$teens_data['total_teens2']); ?>;
            var teachers = <?php echo json_encode((int)$teachers_data['total_teachers']); ?>;
            var pending = <?php echo json_encode((int)$pending_data['total_pending']); ?>;
            var approved = <?php echo json_encode((int)$approved_data['total_approved']); ?>;

            // Debugging: Log values in console
            console.log("Chart Data:", {
                children1,
                children2,
                children3,
                teens1,
                teens2,
                teachers,
                pending,
                approved
            });

            // If all values are 0, show a message instead of an empty chart
            if ([children1, children2, children3, teens1, teens2, teachers, pending, approved].every(val => val === 0)) {
                document.getElementById("chart").innerHTML = "<p style='text-align: center; color: red;'>No registration data available.</p>";
                document.getElementById("chart-data").innerHTML = ""; // Clear data display
                return;
            }

            // Create ApexCharts Bar Chart
            var options = {
                chart: {
                    type: 'bar',
                    height: 400
                },
                series: [{
                        name: 'Children (1-5)',
                        data: [children1]
                    },
                    {
                        name: 'Children (6-8)',
                        data: [children2]
                    },
                    {
                        name: 'Children (9-12)',
                        data: [children3]
                    },
                    {
                        name: 'Teens (13-15)',
                        data: [teens1]
                    },
                    {
                        name: 'Teens (16-above)',
                        data: [teens2]
                    },
                    {
                        name: 'Teachers',
                        data: [teachers]
                    },
                    {
                        name: 'Pending Registrations',
                        data: [pending]
                    },
                    {
                        name: 'Approved Registrations',
                        data: [approved]
                    }
                ],
                xaxis: {
                    categories: [
                        'Children (1-5)', 'Children (6-8)', 'Children (9-12)',
                        'Teens (13-15)', 'Teens (16-above)', 'Teachers',
                        'Pending Reg.', 'Approved Reg.'
                    ]
                },
                colors: ['#3bc0c3', '#1a2942', '#d1d7d9', '#ff4560', '#00e396', '#00e396', '#FFC107', '#28A745']
            };

            var chart = new ApexCharts(document.querySelector("#chart"), options);
            chart.render();

            // Display Data Below the Chart
            var chartDataHtml = `
        <div class="row text-center mt-3">
            <div class="col-md-3"><strong>Children (1-5):</strong> ${children1}</div>
            <div class="col-md-3"><strong>Children (6-8):</strong> ${children2}</div>
            <div class="col-md-3"><strong>Children (9-12):</strong> ${children3}</div>
            <div class="col-md-3"><strong>Teens (13-15):</strong> ${teens1}</div>
            <div class="col-md-3"><strong>Teens (16-above):</strong> ${teens2}</div>
            <div class="col-md-3"><strong>Teachers:</strong> ${teachers}</div>
            <div class="col-md-3"><strong>Pending Registrations:</strong> ${pending}</div>
            <div class="col-md-3"><strong>Approved Registrations:</strong> ${approved}</div>
        </div>
    `;
            document.getElementById("chart-data").innerHTML = chartDataHtml;
        });
    </script>
    <script>
        // Line Chart for Monthly Junior Church Attendance Report
        // Pass PHP data to JavaScript
        var approvedCount = <?php echo json_encode($approvedCount); ?>;
        var pendingCount = <?php echo json_encode($pendingCount); ?>;
        var totalCash = <?php echo json_encode($totalCash); ?>;

        // Update Line Chart for Registrations
        var options2 = {
            chart: {
                type: 'line',
                height: 350
            },
            series: [{
                name: 'Registrations',
                data: [approvedCount, pendingCount, totalCash] // Data for Approved, Pending, and Total Cash
            }],
            xaxis: {
                categories: ['Approved', 'Pending', 'Total Cash']
            },
            colors: ['#3bc0c3']
        };

        var chart2 = new ApexCharts(document.querySelector("#yearly-sales-chart"), options2);
        chart2.render();
    </script>


    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const toggle = document.getElementById('theme-toggle');
            const icon = document.getElementById('theme-icon');

            function applyDarkMode() {
                document.body.classList.add('dark-mode');
                document.body.classList.remove('light-mode');
                if (icon) {
                    icon.classList.remove('fa-sun');
                    icon.classList.add('fa-moon');
                }
                localStorage.setItem('theme', 'dark');
            }

            function applyLightMode() {
                document.body.classList.add('light-mode');
                document.body.classList.remove('dark-mode');
                if (icon) {
                    icon.classList.remove('fa-moon');
                    icon.classList.add('fa-sun');
                }
                localStorage.setItem('theme', 'light');
            }

            // Check and apply the saved theme
            if (localStorage.getItem('theme') === 'dark') {
                applyDarkMode();
            } else {
                applyLightMode();
            }

            // Toggle event listener
            if (toggle) {
                toggle.addEventListener('click', function() {
                    if (document.body.classList.contains('dark-mode')) {
                        applyLightMode();
                    } else {
                        applyDarkMode();
                    }
                });
            }
        });
    </script>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Function to update countdowns
            function updateCountdowns() {
                const countdowns = document.querySelectorAll('.countdown');

                countdowns.forEach(function(countdown) {
                    const eventDate = new Date(countdown.getAttribute('data-event-date')).getTime();
                    const now = new Date().getTime();
                    const distance = eventDate - now;

                    if (distance > 0) {
                        const days = Math.floor(distance / (1000 * 60 * 60 * 24));
                        const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
                        const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
                        const seconds = Math.floor((distance % (1000 * 60)) / 1000);

                        countdown.innerHTML = `
                        <div class="countdown-box">
                            ${days}<span>Days</span>
                        </div>
                        <div class="countdown-box">
                            ${hours}<span>Hours</span>
                        </div>
                        <div class="countdown-box">
                            ${minutes}<span>Minutes</span>
                        </div>
                        <div class="countdown-box">
                            ${seconds}<span>Seconds</span>
                        </div>
                    `;
                    } else {
                        countdown.innerHTML = "<p class='text-danger'>Event Started!</p>";
                    }
                });
            }

            // Update countdowns every second
            setInterval(updateCountdowns, 1000);
            updateCountdowns(); // Initial call to display the countdown immediately
        });
    </script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Initialize Bootstrap carousel if you haven't already included Bootstrap JS
            const carouselElement = document.getElementById('event-carousel');

            if (carouselElement) {
                // Ensure Bootstrap's carousel plugin is initialized
                new bootstrap.Carousel(carouselElement, {
                    interval: 5000, // Optional: time in ms between slides
                    ride: 'carousel' // Optional: ride the carousel
                });
            }

            // Countdown Timer Functionality
            function updateCountdown() {
                const countdowns = document.querySelectorAll('.countdown');
                const now = new Date();

                countdowns.forEach(countdown => {
                    const eventDate = new Date(countdown.getAttribute('data-event-date'));
                    const timeDifference = eventDate - now;

                    if (timeDifference > 0) {
                        const days = Math.floor(timeDifference / (1000 * 60 * 60 * 24));
                        const hours = Math.floor((timeDifference % (1000 * 60 * 60 * 24)) / (1000 * 60 *
                            60));
                        const minutes = Math.floor((timeDifference % (1000 * 60 * 60)) / (1000 * 60));
                        const seconds = Math.floor((timeDifference % (1000 * 60)) / 1000);

                        countdown.innerHTML = `
                    <div class="countdown-box">${days}<span>Days</span></div>
                    <div class="countdown-box">${hours}<span>Hours</span></div>
                    <div class="countdown-box">${minutes}<span>Minutes</span></div>
                    <div class="countdown-box">${seconds}<span>Seconds</span></div>
                `;
                    } else {
                        countdown.innerHTML = `<div class="countdown-box">Expired</div>`;
                    }
                });
            }

            // Update countdown every second
            setInterval(updateCountdown, 1000);

            // Initial call to populate countdown on page load
            updateCountdown();
        });
        document.addEventListener('DOMContentLoaded', function() {
            const carouselElement = document.getElementById('event-carousel');

            if (carouselElement) {
                new bootstrap.Carousel(carouselElement, {
                    interval: 5000, // Optional: time in ms between slides
                    ride: 'carousel' // Optional: ride the carousel
                });
            }
        });
    </script>
    <script>
        $(document).ready(function() {
            $('#notificationDropdown').on('click', function() {
                $.ajax({
                    url: 'fetch_notifications.php',
                    type: 'GET',
                    data: {
                        zone: '<?php echo $_SESSION['zone']; ?>'
                    },
                    dataType: 'json',
                    success: function(data) {
                        console.log('Fetched notifications:', data);
                        let notificationList = $('#notificationList');
                        notificationList.empty();

                        if (data.length === 0) {
                            notificationList.append(
                                '<div class="dropdown-item">No Notifications</div>');
                        } else {
                            data.forEach(notification => {
                                let createdDate = new Date(notification.created_at);
                                let formattedDate = formatDate(createdDate);
                                let timeAgo = timeSince(createdDate);
                                let unreadBadge = notification.is_read === 0 ?
                                    '<span class="badge badge-danger">Unread</span>' :
                                    '';

                                notificationList.append(`
                            <a class="dropdown-item" href="read_notification.php?id=${notification.id}">
                                ${unreadBadge} ${notification.message}
                                <small class="text-muted">${formattedDate} (${timeAgo})</small>
                            </a>
                        `);
                            });
                        }

                        $('.badge-danger').text(data.length);
                    },
                    error: function(xhr, status, error) {
                        console.error('Error loading notifications:', error);
                    }
                });
            });
        });

        function formatDate(date) {
            const options = {
                day: 'numeric',
                month: 'short',
                year: 'numeric'
            };
            let day = date.getDate();
            let month = date.toLocaleString('default', {
                month: 'short'
            });
            let suffix = day % 10 === 1 && day !== 11 ? 'st' :
                day % 10 === 2 && day !== 12 ? 'nd' :
                day % 10 === 3 && day !== 13 ? 'rd' : 'th';
            return `${day}${suffix} ${month}, ${date.getFullYear()}`;
        }

        function timeSince(date) {
            const seconds = Math.floor((new Date() - date) / 1000);
            let interval = Math.floor(seconds / 31536000);
            if (interval > 1) return interval + " years ago";
            interval = Math.floor(seconds / 2592000);
            if (interval > 1) return interval + " months ago";
            interval = Math.floor(seconds / 86400);
            if (interval > 1) return interval + " days ago";
            interval = Math.floor(seconds / 3600);
            if (interval > 1) return interval + " hours ago";
            interval = Math.floor(seconds / 60);
            if (interval > 1) return interval + " minutes ago";
            return seconds + " seconds ago";
        }
    </script>
    <script>
        document.querySelectorAll('.video-card').forEach(card => {
            card.addEventListener('click', function() {
                let videoId = this.getAttribute('data-id');
                let iframe = this.querySelector('.video-iframe');
                let thumbnail = this.querySelector('.video-thumbnail');
                let playIcon = this.querySelector('.play-icon');

                if (videoId) {
                    iframe.src = `https://www.youtube.com/embed/${videoId}?autoplay=1`;
                    iframe.style.display = "block";
                    thumbnail.style.display = "none";
                    playIcon.style.display = "none";
                }
            });
        });
    </script>

    <!-- Scripts -->

</body>

</html>