

<?php
session_start();

if (isset($_GET['amount']) && isset($_GET['registration_id'])) {
    $amount = $_GET['amount'];
    $registrationId = $_GET['registration_id'];

    // Retrieve registration details from session
    $details = $_SESSION['registration_details'] ?? null;

    // Validate registration details
    if (!$details || $details['reference_code'] !== $registrationId) {
        echo 'Invalid registration details.';
        exit();
    }

    // Extract details
    $email = $details['email'];
    $name = $details['name'];
    $phoneNumber = $details['phone_number'];

    // Create unique transaction reference
    $tx_ref = $details['reference_code'];

    // Validate email
    if (empty($email)) {
        echo 'Email is required.';
        exit();
    }

    // Prepare the Flutterwave request
    $request = [
        'tx_ref' => $tx_ref,
        'amount' => $amount,
        'currency' => 'NGN',
        'redirect_url' => 'https://conventionportal.rccgjuniorchurch.org/validation.php',
        'customer' => [
            'email' => $email,
            'name' => $name,
            'phone_number' => $phoneNumber,
        ],
        'session_duration' => 1440, // Optional: Session duration in minutes
        'max_retry_attempt' => 3, // Optional: Max retry attempts
        'customizations' => [
            'title' => 'Payment for ' . date('Y') . ' Annual Convention Registration',
            'description' => 'Complete your registration payment',
            'logo' => 'https://www.rccg.org/wp-content/uploads/2020/11/rccg-for-web.png', // Optional: Logo URL
        ],
        'meta' => [
            'consumer_id' => 23, // Optional: Example of additional metadata
            'consumer_mac' => '92a3-912ba-1192a'
        ],
        'payment_options' => 'card, banktransfer, ussd' // Optional: Payment methods
    ];

    // Initialize cURL
    $curl = curl_init();

    // Set cURL options
    curl_setopt_array($curl, [
        CURLOPT_URL => 'https://api.flutterwave.com/v3/payments',
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_CUSTOMREQUEST => 'POST',
        CURLOPT_POSTFIELDS => json_encode($request),
        CURLOPT_HTTPHEADER => [
            'Authorization: Bearer FLWSECK-462d8cc0a5ee8dc77bc84fd6d395309b-19212a33682vt-X',  // <!-- FLWSECK-462d8cc0a5ee8dc77bc84fd6d395309b-19212a33682vt-X--> Your test secret key
            'Content-Type: application/json'
        ],
        CURLOPT_SSL_VERIFYPEER => true,
        CURLOPT_SSL_VERIFYHOST => 2
    ]);

    // Execute cURL request
    $response = curl_exec($curl);

    // Check for cURL errors
    if ($response === false) {
        $error = curl_error($curl);
        curl_close($curl);
        echo 'cURL Error: ' . $error;
        exit();
    }

    curl_close($curl);

    // Decode response
    $res = json_decode($response);

    // Log the response for debugging
    error_log('Flutterwave API response: ' . print_r($res, true));

    // Check if response is successful
    if ($res && $res->status === 'success') {
        $link = $res->data->link;
        header('Location: ' . $link);
        exit();
    } else {
        echo 'We cannot process your payment at the moment. Please try again later.';
        // Log the failure reason for debugging
        error_log('Flutterwave response error: ' . print_r($res, true));
    }
} else {
    echo 'Invalid payment details.';
}
?>
